@@ -1,6 +1,11 @@
 #ifndef _ECORE_DATA_H
 # define _ECORE_DATA_H
 
+/* we need this for size_t */
+#include <stddef.h>
+
+#include <Eina.h>
+
 #ifdef EAPI
 # undef EAPI
 #endif
@@ -27,9 +32,6 @@
 # endif
 #endif /* ! _WIN32 */
 
-/* we need this for size_t */
-#include <stddef.h>
-
 /**
  * @file Ecore_Data.h
  * @brief Contains threading, list, hash, debugging and tree functions.
@@ -298,7 +300,7 @@ extern "C" {
 
    struct _ecore_path_group
      {
-	Ecore_List *paths;
+	Eina_List *paths;
      };
    
    /*
@@ -329,7 +331,7 @@ extern "C" {
    /*
     * Get a list of all the available files in a path set
     */
-   EAPI Ecore_List * ecore_path_group_available(Ecore_Path_Group *group);
+   EAPI Eina_List * ecore_path_group_available_get(Ecore_Path_Group *group);
    
    
    typedef struct _ecore_plugin Ecore_Plugin;
@@ -353,7 +355,7 @@ extern "C" {
     */
    EAPI void *ecore_plugin_symbol_get(Ecore_Plugin * plugin, const char *symbol_name);
 
-   EAPI Ecore_List *ecore_plugin_available_get(Ecore_Path_Group *group);
+   EAPI Eina_List *ecore_plugin_available_get(Ecore_Path_Group *group);
 
 
    typedef struct _ecore_heap Ecore_Sheap;
@@ -387,20 +389,13 @@ extern "C" {
    
    EAPI void *ecore_sheap_item(Ecore_Sheap *heap, int i);
    
-   
-   typedef struct _ecore_string Ecore_String;
-   struct _ecore_string {
-      char *string;
-      int references;
-   };
-   
-   EAPI int ecore_string_init(void);
-   EAPI void ecore_string_shutdown(void);
-   EAPI const char *ecore_string_instance(const char *string);
-   EAPI void ecore_string_release(const char *string);
-   EAPI void ecore_string_hash_dump_graph(void);
-   EAPI void ecore_string_hash_dump_stats(void);
-   
+  #define ecore_string_init eina_init
+  #define ecore_string_shutdown eina_shutdown
+  #define ecore_string_instance eina_stringshare_add
+  #define ecore_string_release eina_stringshare_del
+
+  #define ecore_string_hash_dump_graph (void)0
+  #define ecore_string_hash_dump_stats (void)0
    
    typedef struct _Ecore_Tree_Node Ecore_Tree_Node;
 # define ECORE_TREE_NODE(object) ((Ecore_Tree_Node *)object)
