@@ -1,3 +1,13 @@
+/*
+ * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
+ */
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+#include <stdlib.h>
+
 #include "ecore_private.h"
 #include "Ecore.h"
 
@@ -11,12 +21,12 @@ static int             poller_walking = 0;
 static double          poll_interval = 0.125;
 static double          poll_cur_interval = 0.0;
 static double          last_tick = 0.0;
-static Ecore_Poller   *pollers[16] = 
+static Ecore_Poller   *pollers[16] =
 {
    NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,
    NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL
 };
-static unsigned short  poller_counters[16] = 
+static unsigned short  poller_counters[16] =
 {
    0,0,0,0,0,0,0,0,
    0,0,0,0,0,0,0,0
@@ -30,7 +40,7 @@ _ecore_poller_next_tick_eval(void)
 {
    int i;
    double interval;
-   
+
    min_interval = -1;
    for (i = 0; i < 15; i++)
      {
@@ -64,7 +74,7 @@ _ecore_poller_next_tick_eval(void)
    else
      {
 	double t;
-	
+
 	if (!timer)
 	  timer = ecore_timer_add(interval, _ecore_poller_cb_timer, NULL);
 	else
@@ -76,7 +86,7 @@ _ecore_poller_next_tick_eval(void)
 		  /* delete the timer and reset it to tick off in the new
 		   * time interval. at the tick this will be adjusted */
 		  ecore_timer_del(timer);
-		  timer = ecore_timer_add(interval - t, 
+		  timer = ecore_timer_add(interval - t,
 					  _ecore_poller_cb_timer, NULL);
 	       }
 	  }
@@ -85,11 +95,10 @@ _ecore_poller_next_tick_eval(void)
 }
 
 static int
-_ecore_poller_cb_timer(void *data)
+_ecore_poller_cb_timer(void *data __UNUSED__)
 {
    int i;
-   Ecore_List2 *l;
-   Ecore_Poller *poller;
+   Ecore_Poller *poller, *l;
    int changes = 0;
 
    at_tick++;
@@ -103,7 +112,7 @@ _ecore_poller_cb_timer(void *data)
 	/* wrap back to 0 if we exceed out loop count for the counter */
 	if (poller_counters[i] >= (1 << i)) poller_counters[i] = 0;
      }
-   
+
    just_added_poller = 0;
    /* walk the pollers now */
    poller_walking++;
@@ -113,9 +122,8 @@ _ecore_poller_cb_timer(void *data)
 	 * tick interval, so run all pollers hooked to that counter */
 	if (poller_counters[i] == 0)
 	  {
-	     for (l = (Ecore_List2 *)pollers[i]; l; l = l->next)
+	     EINA_INLIST_FOREACH(pollers[i], poller)
 	       {
-		  poller = (Ecore_Poller *)l;
 		  if (!poller->delete_me)
 		    {
 		       if (!poller->func(poller->data))
@@ -131,20 +139,20 @@ _ecore_poller_cb_timer(void *data)
 	  }
      }
    poller_walking--;
-	
+
    /* handle deletes afterwards */
    if (poller_delete_count > 0)
      {
 	/* FIXME: walk all pollers and remove deleted ones */
 	for (i = 0; i < 15; i++)
 	  {
-             for (l = (Ecore_List2 *)pollers[i]; l;)
+             for (l = pollers[i]; l;)
 	       {
-                  poller = (Ecore_Poller *)l;
-		  l = l->next;
+                  poller = l;
+		  l = (Ecore_Poller *) EINA_INLIST_GET(l)->next;
 		  if (poller->delete_me)
 		    {
-		       pollers[poller->ibit] = _ecore_list2_remove(pollers[poller->ibit], poller);
+		       pollers[i] = (Ecore_Poller *) eina_inlist_remove(EINA_INLIST_GET(pollers[i]), EINA_INLIST_GET(poller));
 		       free(poller);
 		       poller_delete_count--;
 		       changes++;
@@ -161,11 +169,11 @@ _ecore_poller_cb_timer(void *data)
 
    just_added_poller = 0;
    poller_delete_count = 0;
-   
+
    at_tick--;
-   
+
    /* if the timer was deleted then there is no point returning 1 - ambiguous
-    * if we do as it im plies "keep running me" but we have been deleted 
+    * if we do as it im plies "keep running me" but we have been deleted
     * anyway */
    if (!timer) return 0;
 
@@ -189,27 +197,27 @@ _ecore_poller_cb_timer(void *data)
  * @param   type The ticker type to adjust
  * @param   poll_time The time (in seconds) between ticks of the clock
  * @ingroup Ecore_Poller_Group
- * 
+ *
  * This will adjust the time between ticks of the given ticker type defined
  * by @p type to the time period defined by @p poll_time.
  */
 EAPI void
-ecore_poller_poll_interval_set(Ecore_Poller_Type type, double poll_time)
+ecore_poller_poll_interval_set(Ecore_Poller_Type type __UNUSED__, double poll_time)
 {
    poll_interval = poll_time;
    _ecore_poller_next_tick_eval();
 }
 
 /**
- * Gets the time between ticks (in seconds) for the fiven ticker clock.
+ * Gets the time between ticks (in seconds) for the given ticker clock.
  * @param   type The ticker type to query
  * @return  The time in seconds between ticks of the ticker clock
  * @ingroup Ecore_Poller_Group
- * 
+ *
  * This will get the time between ticks of the specifider ticker clock.
  */
 EAPI double
-ecore_poller_poll_interval_get(Ecore_Poller_Type type)
+ecore_poller_poll_interval_get(Ecore_Poller_Type type __UNUSED__)
 {
    return poll_interval;
 }
@@ -233,7 +241,7 @@ ecore_poller_poll_interval_get(Ecore_Poller_Type type)
  * save power as the CPU has more of a chance to go into a low power state
  * the longer it is asleep for, so this should be used if you are at all
  * power conscious.
- * 
+ *
  * The @p type parameter defines the poller tick type (there is a virtual
  * clock ticking all the time - though ecore avoids making it tick when
  * there will not be any work to do at that tick point). There is only one
@@ -241,7 +249,7 @@ ecore_poller_poll_interval_get(Ecore_Poller_Type type)
  * expansion if multiple clocks with different frequencies are really required.
  * The default time between ticks for the ECORE_POLLER_CORE ticker is 0.125
  * seconds.
- * 
+ *
  * The @p interval is the number of ticker ticks that will pass by in between
  * invocations of the @p func callback. This must be between 1 and 32768
  * inclusive, and must be a power of 2 (i.e. 1, 2, 4, 8, 16, ... 16384, 32768).
@@ -250,26 +258,26 @@ ecore_poller_poll_interval_get(Ecore_Poller_Type type)
  * which tick is undefined, as only the interval between calls can be defined.
  * Ecore will endeavour to keep pollers synchronised and to call as many in
  * 1 wakeup event as possible.
- * 
+ *
  * This function adds a poller and returns its handle on success and NULL on
  * failure. The function @p func will be called at tick intervals described
  * above. The function will be passed the @p data pointer as its parameter.
- * 
- * When the poller @p func is called, it must return a value of either 
- * 1 (or ECORE_CALLBACK_RENEW) or 0 (or ECORE_CALLBACK_CANCEL). If it 
+ *
+ * When the poller @p func is called, it must return a value of either
+ * 1 (or ECORE_CALLBACK_RENEW) or 0 (or ECORE_CALLBACK_CANCEL). If it
  * returns 1, it will be called again at the next tick, or if it returns
  * 0 it will be deleted automatically making any references/handles for it
  * invalid.
  */
 EAPI Ecore_Poller *
-ecore_poller_add(Ecore_Poller_Type type, int interval, int (*func) (void *data), const void *data)
+ecore_poller_add(Ecore_Poller_Type type __UNUSED__, int interval, int (*func) (void *data), const void *data)
 {
    Ecore_Poller *poller;
    int ibit;
-   
+
    if (!func) return NULL;
    if (interval < 1) interval = 1;
-   
+
    poller = calloc(1, sizeof(Ecore_Poller));
    if (!poller) return NULL;
    ECORE_MAGIC_SET(poller, ECORE_MAGIC_POLLER);
@@ -283,11 +291,11 @@ ecore_poller_add(Ecore_Poller_Type type, int interval, int (*func) (void *data),
      }
    /* only allow up to 32768 - i.e. ibit == 15, so limit it */
    if (ibit > 15) ibit = 15;
-   
+
    poller->ibit = ibit;
    poller->func = func;
    poller->data = (void *)data;
-   pollers[poller->ibit] = _ecore_list2_prepend(pollers[poller->ibit], poller);
+   pollers[poller->ibit] = (Ecore_Poller *) eina_inlist_prepend(EINA_INLIST_GET(pollers[poller->ibit]), EINA_INLIST_GET(poller));
    if (poller_walking)
      just_added_poller++;
    else
@@ -309,7 +317,7 @@ EAPI void *
 ecore_poller_del(Ecore_Poller *poller)
 {
    void *data;
-   
+
    if (!ECORE_MAGIC_CHECK(poller, ECORE_MAGIC_POLLER))
      {
 	ECORE_MAGIC_FAIL(poller, ECORE_MAGIC_POLLER,
@@ -327,7 +335,7 @@ ecore_poller_del(Ecore_Poller *poller)
      }
    /* not in loop so safe - delete immediately */
    data = poller->data;
-   pollers[poller->ibit] = _ecore_list2_remove(pollers[poller->ibit], poller);
+   pollers[poller->ibit] = (Ecore_Poller *) eina_inlist_remove(EINA_INLIST_GET(pollers[poller->ibit]), EINA_INLIST_GET(poller));
    free(poller);
    _ecore_poller_next_tick_eval();
    return data;
@@ -337,16 +345,13 @@ void
 _ecore_poller_shutdown(void)
 {
    int i;
-   Ecore_List2 *l;
    Ecore_Poller *poller;
-   
+
    for (i = 0; i < 15; i++)
      {
-	for (l = (Ecore_List2 *)pollers[i]; l;)
+	while ((poller = pollers[i]))
 	  {
-	     poller = (Ecore_Poller *)l;
-	     l = l->next;
-	     pollers[poller->ibit] = _ecore_list2_remove(pollers[poller->ibit], poller);
+	     pollers[i] = (Ecore_Poller *) eina_inlist_remove(EINA_INLIST_GET(pollers[i]), EINA_INLIST_GET(pollers[i]));
 	     free(poller);
 	  }
      }
