@@ -17,13 +17,23 @@
  * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  */
 
-#include <sys/types.h>
+/*
+ * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
+ */
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+#include <stdlib.h>
 #include <string.h>
+#include <limits.h>
+#include <sys/types.h>
 
 #include "ecore_private.h"
 #include "Ecore_Str.h"
 
-static int ecore_str_has_suffix_helper(const char *str, const char *suffix, 
+static int ecore_str_has_suffix_helper(const char *str, const char *suffix,
 		int (*cmp)(const char *, const char *));
 /**
  * @param dst the destination
@@ -73,7 +83,7 @@ ecore_strlcpy(char *dst, const char *src, size_t siz)
  * @param dst the destination
  * @param src the source
  * @param siz the size of the destination
- * @return the length of the source string plus MIN(siz, strlen(initial dst)) 
+ * @return the length of the source string plus MIN(siz, strlen(initial dst))
  * @brief append a c-string
  *
  * Appends src to string dst of size siz (unlike strncat, siz is the
@@ -144,7 +154,7 @@ ecore_str_has_suffix(const char *str, const char *suffix)
 {
    CHECK_PARAM_POINTER_RETURN("str", str, 0);
    CHECK_PARAM_POINTER_RETURN("suffix", suffix, 0);
-   
+
    return ecore_str_has_suffix_helper(str, suffix, strcmp);
 }
 
@@ -162,16 +172,16 @@ ecore_str_has_extension(const char *str, const char *ext)
 {
    CHECK_PARAM_POINTER_RETURN("str", str, 0);
    CHECK_PARAM_POINTER_RETURN("ext", ext, 0);
-   
+
    return ecore_str_has_suffix_helper(str, ext, strcasecmp);
 }
 
 /*
- * Internal helper function used by ecore_str_has_suffix() and 
+ * Internal helper function used by ecore_str_has_suffix() and
  * ecore_str_has_extension()
  */
 static int
-ecore_str_has_suffix_helper(const char *str, const char *suffix, 
+ecore_str_has_suffix_helper(const char *str, const char *suffix,
 		int (*cmp)(const char *, const char *))
 {
    size_t str_len;
@@ -191,10 +201,10 @@ ecore_str_has_suffix_helper(const char *str, const char *suffix,
  * string array contains the remainder of string.
  *
  * @param str         A string to split.
- * @param delim       A string which specifies the places at which to split the 
- *                    string. The delimiter is not included in any of the 
+ * @param delim       A string which specifies the places at which to split the
+ *                    string. The delimiter is not included in any of the
  *                    resulting strings, unless max_tokens is reached.
- * @param max_tokens  The maximum number of strings to split string into. 
+ * @param max_tokens  The maximum number of strings to split string into.
  *                    If this is less than 1, the string is split completely.
  * @return            A newly-allocated NULL-terminated array of strings.
  *                    To free it: free the first element of the array
@@ -218,7 +228,7 @@ ecore_str_split(const char *str, const char *delim, int max_tokens)
    dlen = strlen(delim);
    s = strdup(str);
    str_array = malloc(sizeof(char *) * (len + 1));
-   for (i = 0; (i < max_tokens) && (sep = strstr(s, delim)); i++) 
+   for (i = 0; (i < max_tokens) && (sep = strstr(s, delim)); i++)
       {
           str_array[i] = s;
           s = sep + dlen;
@@ -228,7 +238,65 @@ ecore_str_split(const char *str, const char *delim, int max_tokens)
    str_array[i++] = s;
    str_array = realloc(str_array, sizeof(char *) * (i + 1));
    str_array[i] = NULL;
- 
+
    return str_array;
 }
 
+/**
+ * Join two strings of known length and store the result in @a dst buffer.
+ *
+ * @param dst where to store the result.
+ * @param size byte size of dst, will write at most (size - 1)
+ *     characters and then the '\0' (null terminator).
+ * @param sep separator character to use.
+ * @param a first string to use, before @a sep.
+ * @param a_len length of @a a, not including '\0' (strlen()-like)
+ * @param b second string to use, after @a sep.
+ * @param b_len length of @a b, not including '\0' (strlen()-like)
+ *
+ * @return the number of characters printed (not including the
+ *     trailing '\0' used to end output to strings). Just like
+ *     snprintf(), it will not write more than @a size bytes, thus a
+ *     return value of @a size or more means that the output was
+ *     truncated.
+ *
+ * @see ecore_str_join() and ecore_str_join_static()
+ */
+size_t
+ecore_str_join_len(char *dst, size_t size, char sep, const char *a, size_t a_len, const char *b, size_t b_len)
+{
+   size_t ret = a_len + b_len + 1;
+   size_t off;
+
+   if (size < 1) return ret;
+
+   if (size <= a_len)
+     {
+	memcpy(dst, a, size - 1);
+	dst[size - 1] = '\0';
+	return ret;
+     }
+
+   memcpy(dst, a, a_len);
+   off = a_len;
+
+   if (size <= off + 1)
+     {
+	dst[size - 1] = '\0';
+	return ret;
+     }
+
+   dst[off] = sep;
+   off++;
+
+   if (size <= off + b_len + 1)
+     {
+	memcpy(dst + off, b, size - off - 1);
+	dst[size - 1] = '\0';
+	return ret;
+     }
+
+   memcpy(dst + off, b, b_len);
+   dst[off + b_len] = '\0';
+   return ret;
+}
