@@ -73,24 +73,27 @@ int ECORE_CON_EVENT_URL_PROGRESS = 0;
 #ifdef HAVE_CURL
 static int _ecore_con_url_fd_handler(void *data, Ecore_Fd_Handler *fd_handler);
 static int _ecore_con_url_perform(Ecore_Con_Url *url_con);
+static size_t _ecore_con_url_header_cb(void *ptr, size_t size, size_t nitems, void *stream);
 static size_t _ecore_con_url_data_cb(void *buffer, size_t size, size_t nitems, void *userp);
 static int _ecore_con_url_progress_cb(void *clientp, double dltotal, double dlnow, double ultotal, double ulnow);
 static size_t _ecore_con_url_read_cb(void *ptr, size_t size, size_t nitems, void *stream);
 static void _ecore_con_event_url_free(void *data __UNUSED__, void *ev);
 static int _ecore_con_url_process_completed_jobs(Ecore_Con_Url *url_con_to_match);
+static int _ecore_con_url_idler_handler(void *data __UNUSED__);
 
-static Ecore_Idler	*_fd_idler_handler = NULL;
-static Eina_List	*_url_con_list = NULL;
-static CURLM		*curlm = NULL;
-static fd_set		 _current_fd_set;
-static int		 init_count = 0;
+static Ecore_Idler *_fd_idler_handler = NULL;
+static Eina_List *_url_con_list = NULL;
+static CURLM *curlm = NULL;
+static fd_set _current_fd_set;
+static int init_count = 0;
+static Ecore_Timer *_curl_timeout = NULL;
 
+typedef struct _Ecore_Con_Url_Event Ecore_Con_Url_Event;
 struct _Ecore_Con_Url_Event
 {
-  int    type;
-  void  *ev;
+   int type;
+   void  *ev;
 };
-typedef struct _Ecore_Con_Url_Event Ecore_Con_Url_Event;
 
 static int
 _url_complete_idler_cb(void *data)
@@ -98,7 +101,6 @@ _url_complete_idler_cb(void *data)
    Ecore_Con_Url_Event *lev;
 
    lev = data;
-
    ecore_event_add(lev->type, lev->ev, _ecore_con_event_url_free, NULL);
    free(lev);
 
@@ -129,6 +131,10 @@ EAPI int
 ecore_con_url_init(void)
 {
 #ifdef HAVE_CURL
+   init_count++;
+
+   if (init_count > 1) return init_count;
+
    if (!ECORE_CON_EVENT_URL_DATA)
      {
 	ECORE_CON_EVENT_URL_DATA = ecore_event_type_new();
@@ -138,6 +144,8 @@ ecore_con_url_init(void)
 
    if (!curlm)
      {
+	long ms;
+
 	FD_ZERO(&_current_fd_set);
 	if (curl_global_init(CURL_GLOBAL_NOTHING))
 	  {
@@ -151,10 +159,17 @@ ecore_con_url_init(void)
 	  {
 	     while (_url_con_list)
 	       ecore_con_url_destroy(eina_list_data_get(_url_con_list));
+
+	     init_count--;
 	     return 0;
 	  }
+
+	curl_multi_timeout(curlm, &ms);
+	if (ms <= 0) ms = 1000;
+
+	_curl_timeout = ecore_timer_add((double) ms / 1000, _ecore_con_url_idler_handler, (void *) 0xACE);
+	ecore_timer_freeze(_curl_timeout);
      }
-   init_count++;
    return 1;
 #else
    return 0;
@@ -170,10 +185,20 @@ EAPI int
 ecore_con_url_shutdown(void)
 {
 #ifdef HAVE_CURL
-   if (!init_count)
-     return 0;
+   if (!init_count) return 0;
 
    init_count--;
+
+   if (init_count != 0) return init_count;
+
+   if (_fd_idler_handler)
+     ecore_idler_del(_fd_idler_handler);
+   _fd_idler_handler = NULL;
+
+   if (_curl_timeout)
+     ecore_timer_del(_curl_timeout);
+   _curl_timeout = NULL;
+
    while (_url_con_list)
      ecore_con_url_destroy(eina_list_data_get(_url_con_list));
 
@@ -189,9 +214,20 @@ ecore_con_url_shutdown(void)
 }
 
 /**
- * Creates and initializes a new Ecore_Con_Url.
- * @return  NULL on error, a new Ecore_Con_Url on success.
+ * Creates and initializes a new Ecore_Con_Url connection object.
+ *
+ * Creates and initializes a new Ecore_Con_Url connection object that can be
+ * uesd for sending requests.
+ *
+ * @param url URL that will receive requests. Can be changed using
+ *            ecore_con_url_url_set.
+ *
+ * @return NULL on error, a new Ecore_Con_Url on success.
+ *
  * @ingroup Ecore_Con_Url_Group
+ *
+ * @see ecore_con_url_custom_new()
+ * @see ecore_con_url_url_set()
  */
 EAPI Ecore_Con_Url *
 ecore_con_url_new(const char *url)
@@ -215,13 +251,18 @@ ecore_con_url_new(const char *url)
 
    ecore_con_url_url_set(url_con, url);
 
-   curl_easy_setopt(url_con->curl_easy, CURLOPT_WRITEFUNCTION, _ecore_con_url_data_cb);
+   curl_easy_setopt(url_con->curl_easy, CURLOPT_WRITEFUNCTION, 
+                    _ecore_con_url_data_cb);
    curl_easy_setopt(url_con->curl_easy, CURLOPT_WRITEDATA, url_con);
 
-   curl_easy_setopt(url_con->curl_easy, CURLOPT_PROGRESSFUNCTION, _ecore_con_url_progress_cb);
+   curl_easy_setopt(url_con->curl_easy, CURLOPT_PROGRESSFUNCTION, 
+                    _ecore_con_url_progress_cb);
    curl_easy_setopt(url_con->curl_easy, CURLOPT_PROGRESSDATA, url_con);
    curl_easy_setopt(url_con->curl_easy, CURLOPT_NOPROGRESS, FALSE);
 
+   curl_easy_setopt(url_con->curl_easy, CURLOPT_HEADERFUNCTION, _ecore_con_url_header_cb);
+   curl_easy_setopt(url_con->curl_easy, CURLOPT_HEADERDATA, url_con);
+
    /*
     * FIXME: Check that these timeouts are sensible defaults
     * FIXME: Provide a means to change these timeouts
@@ -234,6 +275,8 @@ ecore_con_url_new(const char *url)
 
    url_con->fd = -1;
    url_con->write_fd = -1;
+   url_con->additional_headers = NULL;
+   url_con->response_headers = NULL;
 
    return url_con;
 #else
@@ -243,14 +286,58 @@ ecore_con_url_new(const char *url)
 }
 
 /**
- * Frees the Ecore_Con_Url.
- * @return  FIXME: To be documented.
+ * Creates a custom connection object.
+ *
+ * Creates and initializes a new Ecore_Con_Url for a custom request (e.g. HEAD,
+ * SUBSCRIBE and other obscure HTTP requests). This object should be used like
+ * one created with ecore_con_url_new().
+ *
+ * @param url URL that will receive requests
+ * @param custom_request Custom request (e.g. GET, POST, HEAD, PUT, etc)
+ *
+ * @return NULL on error, a new Ecore_Con_Url on success.
+ *
  * @ingroup Ecore_Con_Url_Group
+ *
+ * @see ecore_con_url_new()
+ * @see ecore_con_url_url_set()
+ */
+EAPI Ecore_Con_Url *
+ecore_con_url_custom_new(const char *url, const char *custom_request)
+{
+#ifdef HAVE_CURL
+   Ecore_Con_Url *url_con;
+
+   if (!url) return NULL;
+   if (!custom_request) return NULL;
+
+   url_con = ecore_con_url_new(url);
+
+   if (!url_con) return NULL;
+
+   curl_easy_setopt(url_con->curl_easy, CURLOPT_CUSTOMREQUEST, custom_request);
+
+   return url_con;
+#else
+   return NULL;
+   url = NULL;
+   custom_request = NULL;
+#endif
+}
+
+/**
+ * Destroys a Ecore_Con_Url connection object.
+ *
+ * @ingroup Ecore_Con_Url_Group
+ *
+ * @see ecore_con_url_new()
  */
 EAPI void
 ecore_con_url_destroy(Ecore_Con_Url *url_con)
 {
 #ifdef HAVE_CURL
+   char *s;
+
    if (!url_con) return;
    if (!ECORE_MAGIC_CHECK(url_con, ECORE_MAGIC_CON_URL))
      {
@@ -259,13 +346,20 @@ ecore_con_url_destroy(Ecore_Con_Url *url_con)
      }
 
    ECORE_MAGIC_SET(url_con, ECORE_MAGIC_NONE);
-   if (url_con->fd_handler)
+   if(url_con->fd != -1)
      {
-	ecore_main_fd_handler_del(url_con->fd_handler);
+	FD_CLR(url_con->fd, &_current_fd_set);
+	if (url_con->fd_handler)
+	  ecore_main_fd_handler_del(url_con->fd_handler);
 	url_con->fd = -1;
+	url_con->fd_handler = NULL;
      }
    if (url_con->curl_easy)
      {
+	// FIXME: For an unknown reason, progress continue to arrive after destruction
+	// this prevent any further call to the callback.
+	curl_easy_setopt(url_con->curl_easy, CURLOPT_PROGRESSFUNCTION, NULL);
+
 	if (url_con->active)
 	  {
 	     url_con->active = 0;
@@ -276,6 +370,10 @@ ecore_con_url_destroy(Ecore_Con_Url *url_con)
      }
    _url_con_list = eina_list_remove(_url_con_list, url_con);
    curl_slist_free_all(url_con->headers);
+   EINA_LIST_FREE(url_con->additional_headers, s)
+     free(s);
+   EINA_LIST_FREE(url_con->response_headers, s)
+     free(s);
    free(url_con->url);
    free(url_con);
 #else
@@ -285,8 +383,13 @@ ecore_con_url_destroy(Ecore_Con_Url *url_con)
 }
 
 /**
- * FIXME: To be documented.
- * @return  FIXME: To be documented.
+ * Sets the URL to send the request to.
+ *
+ * @param url_con Connection object through which the request will be sent.
+ * @param url URL that will receive the request
+ *
+ * @return 1 on success, 0 on error.
+ *
  * @ingroup Ecore_Con_Url_Group
  */
 EAPI int
@@ -315,9 +418,17 @@ ecore_con_url_url_set(Ecore_Con_Url *url_con, const char *url)
 }
 
 /**
- * FIXME: To be documented.
- * @return  FIXME: To be documented.
+ * Associates data with a connection object.
+ *
+ * Associates data with a connection object, which can be retrieved later with
+ * ecore_con_url_data_get()).
+ *
+ * @param url_con Connection object to associate data.
+ * @param data Data to be set.
+ *
  * @ingroup Ecore_Con_Url_Group
+ *
+ * @see ecore_con_url_data_get()
  */
 EAPI void
 ecore_con_url_data_set(Ecore_Con_Url *url_con, void *data)
@@ -338,9 +449,90 @@ ecore_con_url_data_set(Ecore_Con_Url *url_con, void *data)
 }
 
 /**
- * FIXME: To be documented.
- * @return  FIXME: To be documented.
+ * Adds an additional header to the request connection object.
+ *
+ * Adds an additional header to the request connection object. This addition
+ * will be valid for only one ecore_con_url_send() call.
+ *
+ * @param url_con Connection object
+ * @param key Header key
+ * @param value Header value
+ *
  * @ingroup Ecore_Con_Url_Group
+ *
+ * @see ecore_con_url_send()
+ * @see ecore_con_url_additional_headers_clear()
+ */
+EAPI void
+ecore_con_url_additional_header_add(Ecore_Con_Url *url_con, const char *key, const char *value)
+{
+#ifdef HAVE_CURL
+   char *tmp;
+
+   if (!ECORE_MAGIC_CHECK(url_con, ECORE_MAGIC_CON_URL))
+     {
+	ECORE_MAGIC_FAIL(url_con, ECORE_MAGIC_CON_URL, "ecore_con_url_additional_header_add");
+	return;
+     }
+
+   tmp = malloc(strlen(key) + strlen(value) + 3);
+   if (!tmp) return ;
+   sprintf(tmp, "%s: %s", key, value);
+   url_con->additional_headers = eina_list_append(url_con->additional_headers, tmp);
+#else
+   return;
+   url_con = NULL;
+   key = NULL;
+   value = NULL;
+#endif
+}
+
+/*
+ * Cleans additional headers.
+ *
+ * Cleans additional headers associated with a connection object (previously
+ * added with ecore_con_url_additional_header_add()).
+ *
+ * @param url_con Connection object to clean additional headers.
+ *
+ * @ingroup Ecore_Con_Url_Group
+ *
+ * @see ecore_con_url_additional_header_add()
+ * @see ecore_con_url_send()
+ */
+EAPI void
+ecore_con_url_additional_headers_clear(Ecore_Con_Url *url_con)
+{
+#ifdef HAVE_CURL
+   char *s;
+
+   if (!ECORE_MAGIC_CHECK(url_con, ECORE_MAGIC_CON_URL))
+     {
+	ECORE_MAGIC_FAIL(url_con, ECORE_MAGIC_CON_URL, "ecore_con_url_additional_headers_clear");
+	return;
+     }
+
+   EINA_LIST_FREE(url_con->additional_headers, s)
+     free(s);
+#else
+   return;
+   url_con = NULL;
+#endif
+}
+
+/**
+ * Retrieves data associated with a Ecore_Con_Url connection object.
+ *
+ * Retrieves data associated with a Ecore_Con_Url connection object (previously
+ * set with ecore_con_url_data_set()).
+ *
+ * @param Connection object to retrieve data from.
+ *
+ * @return Data associated with the given object.
+ *
+ * @ingroup Ecore_Con_Url_Group
+ *
+ * @see ecore_con_url_data_set()
  */
 EAPI void *
 ecore_con_url_data_get(Ecore_Con_Url *url_con)
@@ -385,8 +577,15 @@ ecore_con_url_time(Ecore_Con_Url *url_con, Ecore_Con_Url_Time condition, time_t
 }
 
 /**
- * FIXME: To be documented.
- * @return  FIXME: To be documented.
+ * Setup a file for receiving request data.
+ *
+ * Setups a file to have response data written into. Note that
+ * ECORE_CON_EVENT_URL_DATA events will not be emitted if a file has been set to
+ * receive the response data.
+ *
+ * @param url_con Connection object to set file
+ * @param fd File descriptor associated with the file
+ *
  * @ingroup Ecore_Con_Url_Group
  */
 EAPI void
@@ -403,9 +602,18 @@ ecore_con_url_fd_set(Ecore_Con_Url *url_con, int fd)
 }
 
 /**
- * FIXME: To be documented.
- * @return  FIXME: To be documented.
+ * Retrieves the number of bytes received.
+ *
+ * Retrieves the number of bytes received on the last request of the given
+ * connection object.
+ *
+ * @param url_con Connection object which the request was sent on.
+ *
+ * @return Number of bytes received on request.
+ *
  * @ingroup Ecore_Con_Url_Group
+ *
+ * @see ecore_con_url_send()
  */
 EAPI int
 ecore_con_url_received_bytes_get(Ecore_Con_Url *url_con)
@@ -418,19 +626,60 @@ ecore_con_url_received_bytes_get(Ecore_Con_Url *url_con)
      }
 
    return url_con->received;
-#endif
+#else
    return 0;
+#endif
 }
 
 /**
- * FIXME: To be documented.
- * @return  FIXME: To be documented.
+ * Retrieves headers from last request sent.
+ *
+ * Retrieves a list containing the response headers. This function should be
+ * used after an ECORE_CON_EVENT_URL_COMPLETE event (headers should normally be
+ * ready at that time).
+ *
+ * @param url_con Connection object to retrieve response headers from.
+ *
+ * @return List of response headers. This list must not be modified by the user.
+ *
  * @ingroup Ecore_Con_Url_Group
  */
+EAPI const Eina_List *
+ecore_con_url_response_headers_get(Ecore_Con_Url *url_con)
+{
+#ifdef HAVE_CURL
+   return url_con->response_headers;
+#else
+   return NULL;
+#endif
+}
+
+/**
+ * Sends a request.
+ *
+ * @param url_con Connection object to perform a request on, previously created
+ *                with ecore_con_url_new() or ecore_con_url_custom_new().
+ * @param data Payload (data sent on the request)
+ * @param length  Payload length
+ * @param content_type Content type of the payload (e.g. text/xml)
+ *
+ * @return 1 on success, 0 on error.
+ *
+ * @ingroup Ecore_Con_Url_Group
+ *
+ * @see ecore_con_url_custom_new()
+ * @see ecore_con_url_additional_headers_clear()
+ * @see ecore_con_url_additional_header_add()
+ * @see ecore_con_url_data_set()
+ * @see ecore_con_url_data_get()
+ * @see ecore_con_url_response_headers_get()
+ */
 EAPI int
 ecore_con_url_send(Ecore_Con_Url *url_con, const void *data, size_t length, const char *content_type)
 {
 #ifdef HAVE_CURL
+   Eina_List *l;
+   const char *s;
    char tmp[256];
 
    if (!ECORE_MAGIC_CHECK(url_con, ECORE_MAGIC_CON_URL))
@@ -442,6 +691,10 @@ ecore_con_url_send(Ecore_Con_Url *url_con, const void *data, size_t length, cons
    if (url_con->active) return 0;
    if (!url_con->url) return 0;
 
+   /* Free response headers from previous send() calls */
+   EINA_LIST_FREE(url_con->response_headers, s) free((char *)s);
+   url_con->response_headers = NULL;
+
    curl_slist_free_all(url_con->headers);
    url_con->headers = NULL;
 
@@ -462,27 +715,37 @@ ecore_con_url_send(Ecore_Con_Url *url_con, const void *data, size_t length, cons
    switch (url_con->condition)
      {
       case ECORE_CON_URL_TIME_NONE:
-	 curl_easy_setopt(url_con->curl_easy, CURLOPT_TIMECONDITION, CURL_TIMECOND_NONE);
+	 curl_easy_setopt(url_con->curl_easy, CURLOPT_TIMECONDITION, 
+                          CURL_TIMECOND_NONE);
 	 break;
       case ECORE_CON_URL_TIME_IFMODSINCE:
-	 curl_easy_setopt(url_con->curl_easy, CURLOPT_TIMECONDITION, CURL_TIMECOND_IFMODSINCE);
+	 curl_easy_setopt(url_con->curl_easy, CURLOPT_TIMECONDITION, 
+                          CURL_TIMECOND_IFMODSINCE);
 	 curl_easy_setopt(url_con->curl_easy, CURLOPT_TIMEVALUE, url_con->time);
 	 break;
       case ECORE_CON_URL_TIME_IFUNMODSINCE:
-	 curl_easy_setopt(url_con->curl_easy, CURLOPT_TIMECONDITION, CURL_TIMECOND_IFUNMODSINCE);
+	 curl_easy_setopt(url_con->curl_easy, CURLOPT_TIMECONDITION, 
+                          CURL_TIMECOND_IFUNMODSINCE);
 	 curl_easy_setopt(url_con->curl_easy, CURLOPT_TIMEVALUE, url_con->time);
 	 break;
       case ECORE_CON_URL_TIME_LASTMOD:
-	 curl_easy_setopt(url_con->curl_easy, CURLOPT_TIMECONDITION, CURL_TIMECOND_LASTMOD);
+	 curl_easy_setopt(url_con->curl_easy, CURLOPT_TIMECONDITION, 
+                          CURL_TIMECOND_LASTMOD);
 	 curl_easy_setopt(url_con->curl_easy, CURLOPT_TIMEVALUE, url_con->time);
 	 break;
      }
 
+   /* Additional headers */
+   EINA_LIST_FOREACH(url_con->additional_headers, l, s)
+     url_con->headers = curl_slist_append(url_con->headers, s);
+
    curl_easy_setopt(url_con->curl_easy, CURLOPT_HTTPHEADER, url_con->headers);
 
    url_con->received = 0;
 
-   return _ecore_con_url_perform(url_con);
+   int res = _ecore_con_url_perform(url_con);
+
+   return res;
 #else
    return 0;
    url_con = NULL;
@@ -516,24 +779,32 @@ ecore_con_url_ftp_upload(Ecore_Con_Url *url_con, const char *filename, const cha
    if (!url_con->url) return 0;
    if (filename)
      {
+	char tmp[PATH_MAX];
+
+	snprintf(tmp, PATH_MAX, "%s", filename);
+
 	if (stat(filename, &file_info)) return 0;
 	fd = fopen(filename, "rb");
 	if (upload_dir)
-	   snprintf(url, sizeof(url), "ftp://%s/%s/%s", url_con->url, upload_dir, basename(filename));
+	   snprintf(url, sizeof(url), "ftp://%s/%s/%s", url_con->url, 
+                    upload_dir, basename(tmp));
 	else
-	   snprintf(url, sizeof(url), "ftp://%s/%s", url_con->url, basename(filename));
+	   snprintf(url, sizeof(url), "ftp://%s/%s", url_con->url, 
+                    basename(tmp));
 	snprintf(userpwd, sizeof(userpwd), "%s:%s", user, pass);
-	curl_easy_setopt(url_con->curl_easy, CURLOPT_INFILESIZE_LARGE, (curl_off_t)file_info.st_size);
+	curl_easy_setopt(url_con->curl_easy, CURLOPT_INFILESIZE_LARGE, 
+                         (curl_off_t)file_info.st_size);
 	curl_easy_setopt(url_con->curl_easy, CURLOPT_USERPWD, userpwd);
 	curl_easy_setopt(url_con->curl_easy, CURLOPT_UPLOAD, 1);
-	curl_easy_setopt(url_con->curl_easy, CURLOPT_READFUNCTION, _ecore_con_url_read_cb);
+	curl_easy_setopt(url_con->curl_easy, CURLOPT_READFUNCTION, 
+                         _ecore_con_url_read_cb);
 	curl_easy_setopt(url_con->curl_easy, CURLOPT_READDATA, fd);
 	ecore_con_url_url_set(url_con, url);
 
 	return _ecore_con_url_perform(url_con);
      }
    else
-	return 0;
+     return 0;
 #else
    return 0;
    url_con = NULL;
@@ -562,9 +833,9 @@ ecore_con_url_verbose_set(Ecore_Con_Url *url_con, int verbose)
    if (url_con->active) return;
    if (!url_con->url) return;
    if (verbose == TRUE)
-	curl_easy_setopt(url_con->curl_easy, CURLOPT_VERBOSE, 1);
+     curl_easy_setopt(url_con->curl_easy, CURLOPT_VERBOSE, 1);
    else
-	curl_easy_setopt(url_con->curl_easy, CURLOPT_VERBOSE, 0);
+     curl_easy_setopt(url_con->curl_easy, CURLOPT_VERBOSE, 0);
 #endif
 }
 
@@ -586,9 +857,9 @@ ecore_con_url_ftp_use_epsv_set(Ecore_Con_Url *url_con, int use_epsv)
    if (url_con->active) return;
    if (!url_con->url) return;
    if (use_epsv == TRUE)
-	curl_easy_setopt(url_con->curl_easy, CURLOPT_FTP_USE_EPSV, 1);
+     curl_easy_setopt(url_con->curl_easy, CURLOPT_FTP_USE_EPSV, 1);
    else
-	curl_easy_setopt(url_con->curl_easy, CURLOPT_FTP_USE_EPSV, 0);
+     curl_easy_setopt(url_con->curl_easy, CURLOPT_FTP_USE_EPSV, 0);
 #endif
 }
 
@@ -596,12 +867,11 @@ ecore_con_url_ftp_use_epsv_set(Ecore_Con_Url *url_con, int use_epsv)
 static int
 _ecore_con_url_suspend_fd_handler(void)
 {
-   Eina_List		*l;
-   Ecore_Con_Url	*url_con;
-   int			 deleted = 0;
+   Eina_List *l;
+   Ecore_Con_Url *url_con;
+   int deleted = 0;
 
-   if (!_url_con_list)
-     return 0;
+   if (!_url_con_list) return 0;
 
    EINA_LIST_FOREACH(_url_con_list, l, url_con)
      {
@@ -619,21 +889,20 @@ _ecore_con_url_suspend_fd_handler(void)
 static int
 _ecore_con_url_restart_fd_handler(void)
 {
-   Eina_List		*l;
-   Ecore_Con_Url	*url_con;
-   int			 activated = 0;
+   Eina_List *l;
+   Ecore_Con_Url *url_con;
+   int activated = 0;
 
-   if (!_url_con_list)
-     return 0;
+   if (!_url_con_list) return 0;
 
    EINA_LIST_FOREACH(_url_con_list, l, url_con)
      {
 	if (url_con->fd_handler == NULL && url_con->fd != -1)
 	  {
-	     url_con->fd_handler = ecore_main_fd_handler_add(url_con->fd,
-							     url_con->flags,
-							     _ecore_con_url_fd_handler,
-							     NULL, NULL, NULL);
+	     url_con->fd_handler = 
+               ecore_main_fd_handler_add(url_con->fd, url_con->flags,
+                                         _ecore_con_url_fd_handler,
+                                         NULL, NULL, NULL);
 	     activated++;
 	  }
      }
@@ -674,16 +943,15 @@ _ecore_con_url_data_cb(void *buffer, size_t size, size_t nitems, void *userp)
    else
      {
 	ssize_t	count = 0;
-	size_t	total_size = real_size;
-	size_t	offset = 0;
+	size_t total_size = real_size;
+	size_t offset = 0;
 
 	while (total_size > 0)
 	  {
 	     count = write(url_con->write_fd, (char*) buffer + offset, total_size);
 	     if (count < 0)
 	       {
-		  if (errno != EAGAIN && errno != EINTR)
-		    return -1;
+		  if (errno != EAGAIN && errno != EINTR) return -1;
 	       }
 	     else
 	       {
@@ -712,11 +980,28 @@ _ecore_con_url_data_cb(void *buffer, size_t size, size_t nitems, void *userp)
      } \
 }
 
+static size_t
+_ecore_con_url_header_cb(void *ptr, size_t size, size_t nitems, void *stream)
+{
+   size_t real_size = size * nitems;
+   Ecore_Con_Url *url_con = stream;
+
+   char *header = malloc(sizeof(char)*(real_size + 1));
+   if (!header) return real_size;
+   memcpy(header, ptr, real_size);
+   header[real_size] = '\0';
+
+   url_con->response_headers = eina_list_append(url_con->response_headers,
+					        header);
+
+   return real_size;
+}
+
 static int
 _ecore_con_url_progress_cb(void *clientp, double dltotal, double dlnow, double ultotal, double ulnow)
 {
    Ecore_Con_Event_Url_Progress	*e;
-   Ecore_Con_Url		*url_con;
+   Ecore_Con_Url *url_con;
 
    url_con = clientp;
 
@@ -728,7 +1013,8 @@ _ecore_con_url_progress_cb(void *clientp, double dltotal, double dlnow, double u
 	e->down.now = dlnow;
 	e->up.total = ultotal;
 	e->up.now = ulnow;
-	ecore_event_add(ECORE_CON_EVENT_URL_PROGRESS, e, _ecore_con_event_url_free, NULL);
+	ecore_event_add(ECORE_CON_EVENT_URL_PROGRESS, e, 
+                        _ecore_con_event_url_free, NULL);
      }
 
    return 0;
@@ -738,13 +1024,17 @@ static size_t
 _ecore_con_url_read_cb(void *ptr, size_t size, size_t nitems, void *stream)
 {
    size_t retcode = fread(ptr, size, nitems, stream);
-   if (ferror((FILE*)stream)) {
-	fclose(stream);
-	return CURL_READFUNC_ABORT;
-   } else if ((retcode == 0) || (retcode < nitems)) {
-	fclose((FILE*)stream);
-	return 0;
-   }
+
+   if (ferror((FILE*)stream)) 
+     {
+        fclose(stream);
+        return CURL_READFUNC_ABORT;
+     } 
+   else if ((retcode == 0) || (retcode < nitems)) 
+     {
+        fclose((FILE*)stream);
+        return 0;
+     }
    fprintf(stderr, "*** We read %zu bytes from file\n", retcode);
    return retcode;
 }
@@ -753,10 +1043,8 @@ static int
 _ecore_con_url_perform(Ecore_Con_Url *url_con)
 {
    fd_set read_set, write_set, exc_set;
-   int fd_max;
-   int fd;
-   int flags;
-   int still_running;
+   int fd_max, fd;
+   int flags, still_running;
    int completed_immediately = 0;
 
    _url_con_list = eina_list_append(_url_con_list, url_con);
@@ -766,10 +1054,14 @@ _ecore_con_url_perform(Ecore_Con_Url *url_con)
    /* This one can't be stopped, or the download never start. */
    while (curl_multi_perform(curlm, &still_running) == CURLM_CALL_MULTI_PERFORM);
 
-   completed_immediately =  _ecore_con_url_process_completed_jobs(url_con);
+   completed_immediately = _ecore_con_url_process_completed_jobs(url_con);
 
    if (!completed_immediately)
      {
+	if (url_con->fd_handler)
+	  ecore_main_fd_handler_del(url_con->fd_handler);
+	url_con->fd_handler = NULL;
+
 	/* url_con still active -- set up an fd_handler */
 	FD_ZERO(&read_set);
 	FD_ZERO(&write_set);
@@ -787,12 +1079,18 @@ _ecore_con_url_perform(Ecore_Con_Url *url_con)
 		  if (FD_ISSET(fd, &exc_set)) flags |= ECORE_FD_ERROR;
 		  if (flags)
 		    {
+		       long ms = 0;
+
+		       curl_multi_timeout(curlm, &ms);
+		       if (ms == 0) ms = 1000;
+
 		       FD_SET(fd, &_current_fd_set);
 		       url_con->fd = fd;
 		       url_con->flags = flags;
-		       url_con->fd_handler = ecore_main_fd_handler_add(fd, flags,
-								       _ecore_con_url_fd_handler,
-								       NULL, NULL, NULL);
+		       url_con->fd_handler = 
+                         ecore_main_fd_handler_add(fd, flags, 
+                                                   _ecore_con_url_fd_handler,
+                                                   NULL, NULL, NULL);
 		       break;
 		    }
 	       }
@@ -800,22 +1098,23 @@ _ecore_con_url_perform(Ecore_Con_Url *url_con)
 	if (!url_con->fd_handler)
 	  {
 	     /* Failed to set up an fd_handler */
+	     ecore_timer_freeze(_curl_timeout);
 	     curl_multi_remove_handle(curlm, url_con->curl_easy);
 	     url_con->active = 0;
 	     url_con->fd = -1;
 	     return 0;
 	  }
+	ecore_timer_thaw(_curl_timeout);
      }
 
    return 1;
 }
 
 static int
-_ecore_con_url_idler_handler(void *data __UNUSED__)
+_ecore_con_url_idler_handler(void *data)
 {
-   double	start;
-   int		done = 1;
-   int		still_running;
+   double start;
+   int done = 1, still_running;
 
    start = ecore_time_get();
    while (curl_multi_perform(curlm, &still_running) == CURLM_CALL_MULTI_PERFORM)
@@ -832,7 +1131,10 @@ _ecore_con_url_idler_handler(void *data __UNUSED__)
      {
 	_ecore_con_url_restart_fd_handler();
 	_fd_idler_handler = NULL;
-	return 0;
+
+	if (!_url_con_list)
+	  ecore_timer_freeze(_curl_timeout);
+	return data == (void*) 0xACE ? 1 : 0;
      }
 
    return 1;
@@ -870,7 +1172,7 @@ _ecore_con_url_process_completed_jobs(Ecore_Con_Url *url_con_to_match)
 	     if (curlmsg->easy_handle == url_con->curl_easy)
 	       {
 		  if (url_con_to_match && (url_con == url_con_to_match))
-		       job_matched = 1;
+                    job_matched = 1;
 		  if(url_con->fd != -1)
 		    {
 		       FD_CLR(url_con->fd, &_current_fd_set);
@@ -884,11 +1186,17 @@ _ecore_con_url_process_completed_jobs(Ecore_Con_Url *url_con_to_match)
 		  e = calloc(1, sizeof(Ecore_Con_Event_Url_Complete));
 		  if (e)
 		    {
-		       long status;	/* curl API uses long, not int */
 		       e->url_con = url_con;
 		       e->status = 0;
-		       curl_easy_getinfo(curlmsg->easy_handle, CURLINFO_RESPONSE_CODE, &status);
-		       e->status = status;
+		       if (curlmsg->data.result == CURLE_OK)
+			 {
+			    long status;	/* curl API uses long, not int */
+
+			    status = 0;
+			    curl_easy_getinfo(curlmsg->easy_handle, CURLINFO_RESPONSE_CODE, &status);
+			    e->status = status;
+			 }
+
 		       _url_complete_push_event(ECORE_CON_EVENT_URL_COMPLETE, e);
 		    }
 		  curl_multi_remove_handle(curlm, url_con->curl_easy);
