@@ -1,3 +1,11 @@
+/*
+ * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
+ */
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <string.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -8,8 +16,6 @@
 #include "Ecore_Config.h"
 #include "Ecore.h"
 
-#include "config.h"
-
 typedef struct __Ecore_Config_Arg_Callback _Ecore_Config_Arg_Callback;
 struct __Ecore_Config_Arg_Callback
 {
@@ -407,7 +413,7 @@ ecore_config_theme_search_path_get(void)
  *         @c ECORE_CONFIG_ERR_FAIL is returned if @p path is @c NULL.
  */
 int
-ecore_config_theme_search_path_append(char *path)
+ecore_config_theme_search_path_append(const char *path)
 {
    char               *search_path, *loc, *new_search_path;
    int                 len, search_len;
@@ -430,9 +436,9 @@ ecore_config_theme_search_path_append(char *path)
 	strncat(new_search_path, path, len);
 
 	ecore_config_string_set("/e/themes/search_path", new_search_path);
-  prop = ecore_config_get("/e/themes/search_path");
-  if (prop)
-     prop->flags &= ~ECORE_CONFIG_FLAG_MODIFIED;
+	prop = ecore_config_get("/e/themes/search_path");
+	if (prop)
+	  prop->flags &= ~ECORE_CONFIG_FLAG_MODIFIED;
 
 	free(new_search_path);
 
