@@ -1,31 +1,39 @@
 /*
  * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
  */
-#include "config.h"
-#include "Ecore.h"
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
+#include <sys/types.h>
+#include <dirent.h>
+
+#include <Ecore.h>
+#ifdef BUILD_ECORE_EVAS_FB
+#include <Ecore_Fb.h>
+#include <ecore_fb_private.h>
+#endif
+
 #include "ecore_private.h"
 #include "ecore_evas_private.h"
 #include "Ecore_Evas.h"
-#ifdef BUILD_ECORE_EVAS_FB
-#include "Ecore_Fb.h"
-#include "ecore_fb_private.h"
-#endif
 
 #ifdef BUILD_ECORE_EVAS_FB
 static int _ecore_evas_init_count = 0;
 
 static int _ecore_evas_fps_debug = 0;
 static char *ecore_evas_default_display = "0";
-static Ecore_List *ecore_evas_input_devices = NULL;
+static Eina_List *ecore_evas_input_devices = NULL;
 static Ecore_Evas *ecore_evases = NULL;
 static Ecore_Event_Handler *ecore_evas_event_handlers[6] = {NULL, NULL, NULL, NULL, NULL, NULL};
 static Ecore_Idle_Enterer *ecore_evas_idle_enterer = NULL;
 
 static void
-_ecore_evas_mouse_move_process(Ecore_Evas *ee, int x, int y, unsigned int timestamp)
+_ecore_evas_mouse_move_process_fb(Ecore_Evas *ee, int x, int y, unsigned int timestamp)
 {
    int fbw, fbh;
-   
+
    ee->mouse.x = x;
    ee->mouse.y = y;
    ecore_fb_size_get(&fbw, &fbh);
@@ -56,7 +64,7 @@ _ecore_evas_mouse_move_process(Ecore_Evas *ee, int x, int y, unsigned int timest
    else if (ee->rotation == 180)
      evas_event_feed_mouse_move(ee->evas, (fbw - ee->w) + ee->w - x - 1, (fbh - ee->h) + ee->h - y - 1, timestamp, NULL);
    else if (ee->rotation == 270)
-     evas_event_feed_mouse_move(ee->evas, y, (fbw - ee->w) + ee->w - x - 1, timestamp, NULL);   
+     evas_event_feed_mouse_move(ee->evas, y, (fbw - ee->w) + ee->w - x - 1, timestamp, NULL);
 }
 
 static Ecore_Evas *
@@ -68,47 +76,35 @@ _ecore_evas_fb_match(void)
 static void
 _ecore_evas_fb_lose(void *data __UNUSED__)
 {
-   Ecore_List2 *l;
+   Ecore_Evas *ee;
+   Eina_List *ll;
    Ecore_Fb_Input_Device *dev;
 
-   for (l = (Ecore_List2 *)ecore_evases; l; l = l->next)
-     {
-	Ecore_Evas *ee;
-	
-	ee = (Ecore_Evas *)l;
+   EINA_INLIST_FOREACH(ecore_evases, ee)
 	ee->visible = 0;
-     }
-   if (ecore_evas_input_devices)
-     {
-	ecore_list_first_goto(ecore_evas_input_devices);
-	while ((dev = ecore_list_next(ecore_evas_input_devices)))
-	  ecore_fb_input_device_listen(dev, 0);
-     }
+
+   EINA_LIST_FOREACH(ecore_evas_input_devices, ll, dev)
+     ecore_fb_input_device_listen(dev, 0);
 }
 
 static void
 _ecore_evas_fb_gain(void *data __UNUSED__)
 {
-   Ecore_List2 *l;
+   Ecore_Evas *ee;
+   Eina_List *ll;
    Ecore_Fb_Input_Device *dev;
 
-   for (l = (Ecore_List2 *)ecore_evases; l; l = l->next)
+   EINA_INLIST_FOREACH(ecore_evases,ee)
      {
-	Ecore_Evas *ee;
-	
-	ee = (Ecore_Evas *)l;
 	ee->visible = 1;
 	if ((ee->rotation == 90) || (ee->rotation == 270))
 	  evas_damage_rectangle_add(ee->evas, 0, 0, ee->h, ee->w);
 	else
 	  evas_damage_rectangle_add(ee->evas, 0, 0, ee->w, ee->h);
      }
-   if (ecore_evas_input_devices)
-     {
-	ecore_list_first_goto(ecore_evas_input_devices);
-	while ((dev = ecore_list_next(ecore_evas_input_devices)))
-	  ecore_fb_input_device_listen(dev, 1);
-     }
+
+   EINA_LIST_FOREACH(ecore_evas_input_devices, ll, dev)
+     ecore_fb_input_device_listen(dev, 1);
 }
 
 static int
@@ -116,7 +112,7 @@ _ecore_evas_event_key_down(void *data __UNUSED__, int type __UNUSED__, void *eve
 {
    Ecore_Evas *ee;
    Ecore_Fb_Event_Key_Down *e;
-   
+
    e = event;
    ee = _ecore_evas_fb_match();
    if (!ee) return 1; /* pass on event */
@@ -129,7 +125,7 @@ _ecore_evas_event_key_up(void *data __UNUSED__, int type __UNUSED__, void *event
 {
    Ecore_Evas *ee;
    Ecore_Fb_Event_Key_Up *e;
-   
+
    e = event;
    ee = _ecore_evas_fb_match();
    if (!ee) return 1; /* pass on event */
@@ -143,11 +139,11 @@ _ecore_evas_event_mouse_button_down(void *data __UNUSED__, int type __UNUSED__,
    Ecore_Evas *ee;
    Ecore_Fb_Event_Mouse_Button_Down *e;
    Evas_Button_Flags flags = EVAS_BUTTON_NONE;
-   
+
    e = event;
    ee = _ecore_evas_fb_match();
    if (!ee) return 1; /* pass on event */
-   _ecore_evas_mouse_move_process(ee, e->x, e->y, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff));
+   _ecore_evas_mouse_move_process_fb(ee, e->x, e->y, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff));
    if (e->double_click) flags |= EVAS_BUTTON_DOUBLE_CLICK;
    if (e->triple_click) flags |= EVAS_BUTTON_TRIPLE_CLICK;
    evas_event_feed_mouse_down(ee->evas, e->button, flags, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff), NULL);
@@ -159,11 +155,11 @@ _ecore_evas_event_mouse_button_up(void *data __UNUSED__, int type __UNUSED__, vo
 {
    Ecore_Evas *ee;
    Ecore_Fb_Event_Mouse_Button_Up *e;
-   
+
    e = event;
    ee = _ecore_evas_fb_match();
    if (!ee) return 1; /* pass on event */
-   _ecore_evas_mouse_move_process(ee, e->x, e->y, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff));
+   _ecore_evas_mouse_move_process_fb(ee, e->x, e->y, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff));
    evas_event_feed_mouse_up(ee->evas, e->button, EVAS_BUTTON_NONE, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff), NULL);
    return 0; /* dont pass it on */
 }
@@ -173,11 +169,11 @@ _ecore_evas_event_mouse_move(void *data __UNUSED__, int type __UNUSED__, void *e
 {
    Ecore_Evas *ee;
    Ecore_Fb_Event_Mouse_Move *e;
-   
+
    e = event;
    ee = _ecore_evas_fb_match();
    if (!ee) return 1; /* pass on event */
-   _ecore_evas_mouse_move_process(ee, e->x, e->y, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff));
+   _ecore_evas_mouse_move_process_fb(ee, e->x, e->y, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff));
    return 0; /* dont pass it on */
 }
 
@@ -186,51 +182,46 @@ _ecore_evas_event_mouse_wheel(void *data __UNUSED__, int type __UNUSED__, void *
 {
    Ecore_Evas *ee;
    Ecore_Fb_Event_Mouse_Wheel *e;
-   
+
    e = event;
    ee = _ecore_evas_fb_match();
    if (!ee) return 1; /* pass on event */
-   _ecore_evas_mouse_move_process(ee, e->x, e->y, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff));
+   _ecore_evas_mouse_move_process_fb(ee, e->x, e->y, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff));
    return 0; /* dont pass it on */
 }
 
 static int
 _ecore_evas_idle_enter(void *data __UNUSED__)
 {
-   Ecore_List2 *l;
-   double t1 = 0.;
-   double t2 = 0.;
+   Ecore_Evas *ee;
+   double t1 = 0.0;
+   double t2 = 0.0;
 
+   if (!ecore_evases) return 1;
    if (_ecore_evas_fps_debug)
      {
 	t1 = ecore_time_get();
      }
-   for (l = (Ecore_List2 *)ecore_evases; l; l = l->next)
+   EINA_INLIST_FOREACH(ecore_evases, ee)
      {
-	Ecore_Evas *ee;
-	
-	ee = (Ecore_Evas *)l;
 	if (ee->visible)
 	  {
-	     Evas_List *updates;
-	     
-#ifdef BUILD_ECORE_EVAS_BUFFER
-	     Evas_List *ll;
+	     Eina_List *updates;
+
+#ifdef BUILD_ECORE_EVAS_SOFTWARE_BUFFER
+	     Eina_List *ll;
+	     Ecore_Evas *ee2;
 #endif
-	     
 	     if (ee->func.fn_pre_render) ee->func.fn_pre_render(ee);
-#ifdef BUILD_ECORE_EVAS_BUFFER
-	     for (ll = ee->sub_ecore_evas; ll; ll = ll->next)
+#ifdef BUILD_ECORE_EVAS_SOFTWARE_BUFFER
+	     EINA_LIST_FOREACH(ee->sub_ecore_evas, ll, ee2)
 	       {
-		  Ecore_Evas *ee2;
-		  
-		  ee2 = ll->data;
 		  if (ee2->func.fn_pre_render) ee2->func.fn_pre_render(ee2);
 		  _ecore_evas_buffer_render(ee2);
 		  if (ee2->func.fn_post_render) ee2->func.fn_post_render(ee2);
 	       }
-#endif	     
- 	     updates = evas_render_updates(ee->evas);
+#endif
+	     updates = evas_render_updates(ee->evas);
 	     if (updates)
 	       {
 		  evas_render_updates_free(updates);
@@ -256,62 +247,62 @@ _ecore_evas_fb_init(int w, int h)
    Ecore_Fb_Input_Device_Cap caps;
    int mouse_handled = 0;
    int keyboard_handled = 0;
-   
+
    DIR *input_dir;
    struct dirent *input_entry;
-   
+
    _ecore_evas_init_count++;
    if (_ecore_evas_init_count > 1) return _ecore_evas_init_count;
-   
+
    if (getenv("ECORE_EVAS_FPS_DEBUG")) _ecore_evas_fps_debug = 1;
    ecore_evas_idle_enterer = ecore_idle_enterer_add(_ecore_evas_idle_enter, NULL);
    if (_ecore_evas_fps_debug) _ecore_evas_fps_debug_init();
    /* register all input devices */
    input_dir = opendir("/dev/input/");
    if (!input_dir) return _ecore_evas_init_count;
-   
-   ecore_evas_input_devices = ecore_list_new();
+
    while ((input_entry = readdir(input_dir)))
      {
 	char device_path[256];
-	
+
 	if (strncmp(input_entry->d_name, "event", 5) != 0)
 	  continue;
-	
+
 	snprintf(device_path, 256, "/dev/input/%s", input_entry->d_name);
 	if (!(device = ecore_fb_input_device_open(device_path)))
 	  continue;
-	
+
 	caps = ecore_fb_input_device_cap_get(device);
 
-	if (ecore_evas_input_devices)
+	/* Mouse */
+#ifdef HAVE_TSLIB
+	if (caps & ECORE_FB_INPUT_DEVICE_CAP_RELATIVE)
+#else
+	if ((caps & ECORE_FB_INPUT_DEVICE_CAP_RELATIVE) || (caps & ECORE_FB_INPUT_DEVICE_CAP_ABSOLUTE))
+#endif
 	  {
-	     /* Mouse */
-	     if (caps & ECORE_FB_INPUT_DEVICE_CAP_RELATIVE)
+	     ecore_fb_input_device_axis_size_set(device, w, h);
+	     ecore_fb_input_device_listen(device,1);
+	     ecore_evas_input_devices = eina_list_append(ecore_evas_input_devices, device);
+	     if (!mouse_handled)
 	       {
-		  ecore_fb_input_device_axis_size_set(device, w, h);
-		  ecore_fb_input_device_listen(device,1);
-		  ecore_list_append(ecore_evas_input_devices, device);
-		  if (!mouse_handled)
-		    {
-		       ecore_evas_event_handlers[2]  = ecore_event_handler_add(ECORE_FB_EVENT_MOUSE_BUTTON_DOWN, _ecore_evas_event_mouse_button_down, NULL);
-		       ecore_evas_event_handlers[3]  = ecore_event_handler_add(ECORE_FB_EVENT_MOUSE_BUTTON_UP, _ecore_evas_event_mouse_button_up, NULL);
-		       ecore_evas_event_handlers[4]  = ecore_event_handler_add(ECORE_FB_EVENT_MOUSE_MOVE, _ecore_evas_event_mouse_move, NULL);
-		       ecore_evas_event_handlers[5]  = ecore_event_handler_add(ECORE_FB_EVENT_MOUSE_WHEEL, _ecore_evas_event_mouse_wheel, NULL);
-		       mouse_handled = 1;
-		    }
+		  ecore_evas_event_handlers[2]  = ecore_event_handler_add(ECORE_FB_EVENT_MOUSE_BUTTON_DOWN, _ecore_evas_event_mouse_button_down, NULL);
+		  ecore_evas_event_handlers[3]  = ecore_event_handler_add(ECORE_FB_EVENT_MOUSE_BUTTON_UP, _ecore_evas_event_mouse_button_up, NULL);
+		  ecore_evas_event_handlers[4]  = ecore_event_handler_add(ECORE_FB_EVENT_MOUSE_MOVE, _ecore_evas_event_mouse_move, NULL);
+		  ecore_evas_event_handlers[5]  = ecore_event_handler_add(ECORE_FB_EVENT_MOUSE_WHEEL, _ecore_evas_event_mouse_wheel, NULL);
+		  mouse_handled = 1;
 	       }
-	     /* Keyboard */
-	     else if ((caps & ECORE_FB_INPUT_DEVICE_CAP_KEYS_OR_BUTTONS) && !(caps & ECORE_FB_INPUT_DEVICE_CAP_ABSOLUTE))
+	  }
+	/* Keyboard */
+	else if ((caps & ECORE_FB_INPUT_DEVICE_CAP_KEYS_OR_BUTTONS) && !(caps & ECORE_FB_INPUT_DEVICE_CAP_ABSOLUTE))
+	  {
+	     ecore_fb_input_device_listen(device,1);
+	     ecore_evas_input_devices = eina_list_append(ecore_evas_input_devices, device);
+	     if (!keyboard_handled)
 	       {
-		  ecore_fb_input_device_listen(device,1);
-		  ecore_list_append(ecore_evas_input_devices, device);
-		  if (!keyboard_handled)
-		    {
-		       ecore_evas_event_handlers[0]  = ecore_event_handler_add(ECORE_FB_EVENT_KEY_DOWN, _ecore_evas_event_key_down, NULL);
-		       ecore_evas_event_handlers[1]  = ecore_event_handler_add(ECORE_FB_EVENT_KEY_UP, _ecore_evas_event_key_up, NULL);
-		       keyboard_handled = 1;
-		    }
+		  ecore_evas_event_handlers[0]  = ecore_event_handler_add(ECORE_FB_EVENT_KEY_DOWN, _ecore_evas_event_key_down, NULL);
+		  ecore_evas_event_handlers[1]  = ecore_event_handler_add(ECORE_FB_EVENT_KEY_UP, _ecore_evas_event_key_up, NULL);
+		  keyboard_handled = 1;
 	       }
 	  }
      }
@@ -331,7 +322,7 @@ _ecore_evas_fb_init(int w, int h)
 static void
 _ecore_evas_fb_free(Ecore_Evas *ee)
 {
-   ecore_evases = _ecore_list2_remove(ecore_evases, ee);   
+   ecore_evases = (Ecore_Evas *) eina_inlist_remove(EINA_INLIST_GET(ecore_evases), EINA_INLIST_GET(ee));
    _ecore_evas_fb_shutdown();
    ecore_fb_shutdown();
 }
@@ -354,7 +345,7 @@ _ecore_evas_resize(Ecore_Evas *ee, int w, int h)
        evas_output_viewport_set(ee->evas, 0, 0, ee->w, ee->h);
        evas_damage_rectangle_add(ee->evas, 0, 0, ee->w, ee->h);
      }
-   if (ee->func.fn_resize) ee->func.fn_resize(ee);	
+   if (ee->func.fn_resize) ee->func.fn_resize(ee);
 }
 
 static void
@@ -375,7 +366,7 @@ _ecore_evas_move_resize(Ecore_Evas *ee, int x __UNUSED__, int y __UNUSED__, int
        evas_output_viewport_set(ee->evas, 0, 0, ee->w, ee->h);
        evas_damage_rectangle_add(ee->evas, 0, 0, ee->w, ee->h);
      }
-   if (ee->func.fn_resize) ee->func.fn_resize(ee);	
+   if (ee->func.fn_resize) ee->func.fn_resize(ee);
 }
 
 static void
@@ -383,7 +374,7 @@ _ecore_evas_rotation_set(Ecore_Evas *ee, int rotation)
 {
    Evas_Engine_Info_FB *einfo;
    int rot_dif;
-   
+
    if (ee->rotation == rotation) return;
    einfo = (Evas_Engine_Info_FB *)evas_engine_info_get(ee->evas);
    if (!einfo) return;
@@ -391,13 +382,13 @@ _ecore_evas_rotation_set(Ecore_Evas *ee, int rotation)
    if (rot_dif < 0) rot_dif = -rot_dif;
    if (rot_dif != 180)
      {
-	
+
 	einfo->info.rotation = rotation;
 	evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo);
 	if (!ee->prop.fullscreen)
 	  {
 	     int tmp;
-	     
+
 	     tmp = ee->w;
 	     ee->w = ee->h;
 	     ee->h = tmp;
@@ -427,15 +418,25 @@ _ecore_evas_rotation_set(Ecore_Evas *ee, int rotation)
      evas_damage_rectangle_add(ee->evas, 0, 0, ee->h, ee->w);
    else
      evas_damage_rectangle_add(ee->evas, 0, 0, ee->w, ee->h);
-   _ecore_evas_mouse_move_process(ee, ee->mouse.x, ee->mouse.y, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff));
+   _ecore_evas_mouse_move_process_fb(ee, ee->mouse.x, ee->mouse.y, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff));
    if (ee->func.fn_resize) ee->func.fn_resize(ee);
 }
 
+static void
+_ecore_evas_object_cursor_del(void *data, Evas *e __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+{
+   Ecore_Evas *ee;
+
+   ee = data;
+   if (ee)
+     ee->prop.cursor.object = NULL;
+}
+
 static void
 _ecore_evas_object_cursor_set(Ecore_Evas *ee, Evas_Object *obj, int layer, int hot_x, int hot_y)
 {
    int x, y;
-   
+
    if (ee->prop.cursor.object) evas_object_del(ee->prop.cursor.object);
 
    if (obj == NULL)
@@ -453,25 +454,29 @@ _ecore_evas_object_cursor_set(Ecore_Evas *ee, Evas_Object *obj, int layer, int h
    ee->prop.cursor.hot.y = hot_y;
    evas_pointer_output_xy_get(ee->evas, &x, &y);
    evas_object_layer_set(ee->prop.cursor.object, ee->prop.cursor.layer);
-   evas_object_move(ee->prop.cursor.object, 
+   evas_object_move(ee->prop.cursor.object,
 		    x - ee->prop.cursor.hot.x,
 		    y - ee->prop.cursor.hot.y);
    evas_object_pass_events_set(ee->prop.cursor.object, 1);
    if (evas_pointer_inside_get(ee->evas))
      evas_object_show(ee->prop.cursor.object);
+
+   evas_object_event_callback_add(obj, EVAS_CALLBACK_DEL, _ecore_evas_object_cursor_del, ee);
 }
 
 static void
 _ecore_evas_fullscreen_set(Ecore_Evas *ee, int on)
 {
+   Eina_List *l;
+   Ecore_Fb_Input_Device *dev;
    int resized = 0;
-   
+
    if (((ee->prop.fullscreen) && (on)) ||
        ((!ee->prop.fullscreen) && (!on))) return;
    if (on)
      {
 	int w, h;
-	
+
 	ee->engine.fb.real_w = ee->w;
 	ee->engine.fb.real_h = ee->h;
 	w = ee->w;
@@ -499,21 +504,15 @@ _ecore_evas_fullscreen_set(Ecore_Evas *ee, int on)
 	evas_damage_rectangle_add(ee->evas, 0, 0, ee->w, ee->h);
      }
    ee->prop.fullscreen = on;
+   EINA_LIST_FOREACH(ecore_evas_input_devices, l, dev)
+     ecore_fb_input_device_axis_size_set(dev, ee->w, ee->h);
    /* rescale the input device area */
-   if (ecore_evas_input_devices)
-     {
-	Ecore_Fb_Input_Device *dev;
-	
-	ecore_list_first_goto(ecore_evas_input_devices);
-	while ((dev = ecore_list_next(ecore_evas_input_devices)))
-	  ecore_fb_input_device_axis_size_set(dev, ee->w, ee->h);
-     }
    if (resized)
      {
-	if (ee->func.fn_resize) ee->func.fn_resize(ee); 
+	if (ee->func.fn_resize) ee->func.fn_resize(ee);
      }
 }
-    
+
 int
 _ecore_evas_fb_shutdown(void)
 {
@@ -521,7 +520,7 @@ _ecore_evas_fb_shutdown(void)
    if (_ecore_evas_init_count == 0)
      {
 	int i;
-   
+
 	while (ecore_evases) _ecore_evas_free(ecore_evases);
 	for (i = 0; i < 5; i++)
 	  ecore_event_handler_del(ecore_evas_event_handlers[i]);
@@ -579,6 +578,7 @@ static const Ecore_Evas_Engine_Func _ecore_fb_engine_func =
      NULL,
      NULL,
      NULL,
+     NULL,
      NULL
 };
 #endif
@@ -588,10 +588,10 @@ static const Ecore_Evas_Engine_Func _ecore_fb_engine_func =
  *
  * FIXME: To be fixed.
  */
-EAPI Ecore_Evas *
-ecore_evas_fb_new(char *disp_name, int rotation, int w, int h)
-{
 #ifdef BUILD_ECORE_EVAS_FB
+EAPI Ecore_Evas *
+ecore_evas_fb_new(const char *disp_name, int rotation, int w, int h)
+{
    Evas_Engine_Info_FB *einfo;
    Ecore_Evas *ee;
 
@@ -602,7 +602,7 @@ ecore_evas_fb_new(char *disp_name, int rotation, int w, int h)
 
    rmethod = evas_render_method_lookup("fb");
    if (!rmethod) return NULL;
-   
+
    if (!ecore_fb_init(disp_name)) return NULL;
    ecore_fb_callback_gain_set(_ecore_evas_fb_gain, NULL);
    ecore_fb_callback_lose_set(_ecore_evas_fb_lose, NULL);
@@ -610,11 +610,11 @@ ecore_evas_fb_new(char *disp_name, int rotation, int w, int h)
    if (!ee) return NULL;
 
    ECORE_MAGIC_SET(ee, ECORE_MAGIC_EVAS);
-   
+
    _ecore_evas_fb_init(w, h);
-   
+
    ee->engine.func = (Ecore_Evas_Engine_Func *)&_ecore_fb_engine_func;
-   
+
    ee->driver = "fb";
    if (disp_name) ee->name = strdup(disp_name);
 
@@ -635,7 +635,7 @@ ecore_evas_fb_new(char *disp_name, int rotation, int w, int h)
    ee->prop.fullscreen = 0;
    ee->prop.withdrawn = 0;
    ee->prop.sticky = 0;
-   
+
    /* init evas here */
    ee->evas = evas_new();
    evas_data_attach_set(ee->evas, ee);
@@ -671,14 +671,16 @@ ecore_evas_fb_new(char *disp_name, int rotation, int w, int h)
    evas_key_lock_add(ee->evas, "Caps_Lock");
    evas_key_lock_add(ee->evas, "Num_Lock");
    evas_key_lock_add(ee->evas, "Scroll_Lock");
-   
+
    evas_event_feed_mouse_in(ee->evas, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff), NULL);
 
-   ecore_evases = _ecore_list2_prepend(ecore_evases, ee);
+   ecore_evases = (Ecore_Evas *) eina_inlist_prepend(EINA_INLIST_GET(ecore_evases), EINA_INLIST_GET(ee));
    return ee;
-#else
-   disp_name = NULL;
-   rotation = w = h = 0;
-   return NULL;
-#endif   
 }
+#else
+EAPI Ecore_Evas *
+ecore_evas_fb_new(const char *disp_name __UNUSED__, int rotation __UNUSED__, int w __UNUSED__, int h __UNUSED__)
+{
+   return NULL;
+}
+#endif
