@@ -1,14 +1,22 @@
-#include "config.h"
-#include "Ecore.h"
-#include "ecore_private.h"
-#include "ecore_evas_private.h"
-#include "Ecore_Evas.h"
-#ifdef BUILD_ECORE_EVAS_SDL
-#include "Ecore_Sdl.h"
-#include "Evas_Engine_SDL.h"
+/*
+ * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
+ */
+
+#ifdef HAVE_CONFIG_H
+# include <config.h>
 #endif
 
-#ifdef BUILD_ECORE_EVAS_SDL
+#include <Ecore.h>
+#include <Ecore_Input.h>
+#ifdef BUILD_ECORE_EVAS_SOFTWARE_SDL
+#include <Ecore_Sdl.h>
+#include <Evas_Engine_SDL.h>
+#endif
+
+#include "ecore_evas_private.h"
+#include "Ecore_Evas.h"
+
+#ifdef BUILD_ECORE_EVAS_SOFTWARE_SDL
 
 /* static char *ecore_evas_default_display = "0"; */
 /* static Ecore_List *ecore_evas_input_devices = NULL; */
@@ -18,29 +26,14 @@ static int                      _ecore_evas_init_count = 0;
 static int                      _ecore_evas_fps_debug = 0;
 #endif /* _WIN32 */
 static Ecore_Evas               *ecore_evases = NULL;
-static Ecore_Event_Handler      *ecore_evas_event_handlers[10] = {
-   NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL
+static Ecore_Event_Handler      *ecore_evas_event_handlers[4] = {
+   NULL, NULL, NULL, NULL
 };
 static Ecore_Idle_Enterer       *ecore_evas_idle_enterer = NULL;
-static Ecore_Idler              *ecore_evas_event = NULL;
+static Ecore_Poller             *ecore_evas_event = NULL;
 
 static const char               *ecore_evas_sdl_default = "EFL SDL";
 
-static void
-_ecore_evas_mouse_move_process(Ecore_Evas *ee, int x, int y, unsigned int timestamp)
-{
-   ee->mouse.x = x;
-   ee->mouse.y = y;
-   if (ee->prop.cursor.object)
-     {
-	evas_object_show(ee->prop.cursor.object);
-        evas_object_move(ee->prop.cursor.object,
-                         x - ee->prop.cursor.hot.x,
-                         y - ee->prop.cursor.hot.y);
-     }
-   evas_event_feed_mouse_move(ee->evas, x, y, timestamp, NULL);
-}
-
 static Ecore_Evas *
 _ecore_evas_sdl_match(void)
 {
@@ -48,112 +41,7 @@ _ecore_evas_sdl_match(void)
 }
 
 static int
-_ecore_evas_sdl_event_key_down(void *data __UNUSED__, int type __UNUSED__, void *event)
-{
-   Ecore_Sdl_Event_Key_Down     *e;
-   Ecore_Evas                   *ee;
-
-   e = event;
-   ee = _ecore_evas_sdl_match();
-
-   if (!ee) return 1;
-   /* pass on event */
-   evas_event_feed_key_down(ee->evas, e->keyname, NULL, e->keycompose, NULL, e->time, NULL);
-
-   return 0; /* dont pass it on */
-}
-
-static int
-_ecore_evas_sdl_event_key_up(void *data __UNUSED__, int type __UNUSED__, void *event)
-{
-   Ecore_Sdl_Event_Key_Up       *e;
-   Ecore_Evas                   *ee;
-
-   e = event;
-   ee = _ecore_evas_sdl_match();
-
-   if (!ee) return 1;
-   /* pass on event */
-   evas_event_feed_key_up(ee->evas, e->keyname, NULL, e->keycompose, NULL, e->time, NULL);
-
-   return 0;
-}
-
-static int
-_ecore_evas_sdl_event_mouse_move(void *data __UNUSED__, int type __UNUSED__, void *event)
-{
-   Ecore_Sdl_Event_Mouse_Move *e;
-   Ecore_Evas *ee;
-
-   e = event;
-   ee = _ecore_evas_sdl_match();
-
-   if (!ee) return 1; /* pass on event */
-   _ecore_evas_mouse_move_process(ee, e->x, e->y, e->time);
-
-   return 0;
-}
-
-static int
-_ecore_evas_sdl_event_button_down(void *data __UNUSED__, int type __UNUSED__, void *event)
-{
-   Ecore_Sdl_Event_Mouse_Button_Down    *e;
-   Ecore_Evas                           *ee;
-   Evas_Button_Flags                    flags;
-
-   e = event;
-   ee = _ecore_evas_sdl_match();
-   flags = EVAS_BUTTON_NONE;
-
-   if (!ee) return 1;
-   /* pass on event */
-   _ecore_evas_mouse_move_process(ee, e->x, e->y, e->time);
-   if (e->double_click) flags |= EVAS_BUTTON_DOUBLE_CLICK;
-   if (e->triple_click) flags |= EVAS_BUTTON_TRIPLE_CLICK;
-   evas_event_feed_mouse_down(ee->evas, e->button, flags, e->time, NULL);
-
-   return 0;
-}
-
-static int
-_ecore_evas_sdl_event_button_up(void *data __UNUSED__, int type __UNUSED__, void *event)
-{
-   Ecore_Sdl_Event_Mouse_Button_Up      *e;
-   Ecore_Evas                           *ee;
-   Evas_Button_Flags                    flags;
-
-   e = event;
-   ee = _ecore_evas_sdl_match();
-   flags = EVAS_BUTTON_NONE;
-
-   if (!ee) return 1;
-   /* pass on event */
-   _ecore_evas_mouse_move_process(ee, e->x, e->y, e->time);
-   if (e->double_click) flags |= EVAS_BUTTON_DOUBLE_CLICK;
-   if (e->triple_click) flags |= EVAS_BUTTON_TRIPLE_CLICK;
-   evas_event_feed_mouse_up(ee->evas, e->button, flags, e->time, NULL);
-
-   return 0;
-}
-
-static int
-_ecore_evas_sdl_event_mouse_wheel(void *data __UNUSED__, int type __UNUSED__, void *event)
-{
-   Ecore_Sdl_Event_Mouse_Wheel  *e;
-   Ecore_Evas                   *ee;
-
-   e = event;
-   ee = _ecore_evas_sdl_match();
-
-   if (!ee) return 1; /* pass on event */
-   _ecore_evas_mouse_move_process(ee, e->x, e->y, e->time);
-   evas_event_feed_mouse_wheel(ee->evas, e->direction, e->wheel, e->time, NULL);
-
-   return 0;
-}
-
-static int
-_ecore_evas_sdl_event_got_focus(void *data __UNUSED__, int type __UNUSED__, void *event)
+_ecore_evas_sdl_event_got_focus(void *data __UNUSED__, int type __UNUSED__, void *event __UNUSED__)
 {
    Ecore_Evas                   *ee;
 
@@ -167,7 +55,7 @@ _ecore_evas_sdl_event_got_focus(void *data __UNUSED__, int type __UNUSED__, void
 }
 
 static int
-_ecore_evas_sdl_event_lost_focus(void *data __UNUSED__, int type __UNUSED__, void *event)
+_ecore_evas_sdl_event_lost_focus(void *data __UNUSED__, int type __UNUSED__, void *event __UNUSED__)
 {
    Ecore_Evas                   *ee;
 
@@ -214,7 +102,7 @@ _ecore_evas_sdl_event_video_expose(void *data __UNUSED__, int type __UNUSED__, v
 static void
 _ecore_evas_render(Ecore_Evas *ee)
 {
-   Evas_List *updates;
+   Eina_List *updates;
 
    updates = evas_render_updates(ee->evas);
    if (updates)
@@ -227,21 +115,30 @@ _ecore_evas_render(Ecore_Evas *ee)
 static int
 _ecore_evas_idle_enter(void *data __UNUSED__)
 {
-   Ecore_List2  *l;
-   double       t1 = 0.;
-   double       t2 = 0.;
+   Ecore_Evas  *ee;
+   double       t1 = 0.0;
+   double       t2 = 0.0;
 
+   if (!ecore_evases) return 1;
 #ifndef _WIN32
    if (_ecore_evas_fps_debug)
      {
 	t1 = ecore_time_get();
      }
 #endif /* _WIN32 */
-   for (l = (Ecore_List2 *)ecore_evases; l; l = l->next)
+   EINA_INLIST_FOREACH(ecore_evases, ee)
      {
-	Ecore_Evas *ee;
+#ifdef BUILD_ECORE_EVAS_SOFTWARE_BUFFER
+	Eina_List *ll;
+	Ecore_Evas *ee2;
 
-	ee = (Ecore_Evas *)l;
+	EINA_LIST_FOREACH(ee->sub_ecore_evas, ll, ee2)
+	  {
+	     if (ee2->func.fn_pre_render) ee2->func.fn_pre_render(ee2);
+	     _ecore_evas_buffer_render(ee2);
+	     if (ee2->func.fn_post_render) ee2->func.fn_post_render(ee2);
+	  }
+#endif
 
 	if (ee->func.fn_pre_render) ee->func.fn_pre_render(ee);
 
@@ -266,7 +163,7 @@ _ecore_evas_idle_enter(void *data __UNUSED__)
 }
 
 static int
-_ecore_evas_sdl_event(void *data)
+_ecore_evas_sdl_event(void *data __UNUSED__)
 {
    ecore_sdl_feed_events();
 
@@ -274,7 +171,7 @@ _ecore_evas_sdl_event(void *data)
 }
 
 static int
-_ecore_evas_sdl_init(int w, int h)
+_ecore_evas_sdl_init(int w __UNUSED__, int h __UNUSED__)
 {
    _ecore_evas_init_count++;
    if (_ecore_evas_init_count > 1) return _ecore_evas_init_count;
@@ -283,21 +180,18 @@ _ecore_evas_sdl_init(int w, int h)
    if (getenv("ECORE_EVAS_FPS_DEBUG")) _ecore_evas_fps_debug = 1;
 #endif /* _WIN32 */
    ecore_evas_idle_enterer = ecore_idle_enterer_add(_ecore_evas_idle_enter, NULL);
-   ecore_evas_event = ecore_timer_add(0.008, _ecore_evas_sdl_event, NULL);
+   ecore_evas_event = ecore_poller_add(ECORE_POLLER_CORE, 1, _ecore_evas_sdl_event, NULL);
+   ecore_poller_poll_interval_set(ECORE_POLLER_CORE, 0.006);
 #ifndef _WIN32
    if (_ecore_evas_fps_debug) _ecore_evas_fps_debug_init();
 #endif /* _WIN32 */
 
-   ecore_evas_event_handlers[0] = ecore_event_handler_add(ECORE_SDL_EVENT_KEY_DOWN, _ecore_evas_sdl_event_key_down, NULL);
-   ecore_evas_event_handlers[1] = ecore_event_handler_add(ECORE_SDL_EVENT_KEY_UP, _ecore_evas_sdl_event_key_up, NULL);
-   ecore_evas_event_handlers[2] = ecore_event_handler_add(ECORE_SDL_EVENT_MOUSE_BUTTON_DOWN, _ecore_evas_sdl_event_button_down, NULL);
-   ecore_evas_event_handlers[3] = ecore_event_handler_add(ECORE_SDL_EVENT_MOUSE_BUTTON_UP, _ecore_evas_sdl_event_button_up, NULL);
-   ecore_evas_event_handlers[4] = ecore_event_handler_add(ECORE_SDL_EVENT_MOUSE_MOVE, _ecore_evas_sdl_event_mouse_move, NULL);
-   ecore_evas_event_handlers[5] = ecore_event_handler_add(ECORE_SDL_EVENT_MOUSE_WHEEL, _ecore_evas_sdl_event_mouse_wheel, NULL);
-   ecore_evas_event_handlers[6] = ecore_event_handler_add(ECORE_SDL_EVENT_GOT_FOCUS, _ecore_evas_sdl_event_got_focus, NULL);
-   ecore_evas_event_handlers[7] = ecore_event_handler_add(ECORE_SDL_EVENT_LOST_FOCUS, _ecore_evas_sdl_event_lost_focus, NULL);
-   ecore_evas_event_handlers[8] = ecore_event_handler_add(ECORE_SDL_EVENT_RESIZE, _ecore_evas_sdl_event_video_resize, NULL);
-   ecore_evas_event_handlers[9] = ecore_event_handler_add(ECORE_SDL_EVENT_EXPOSE, _ecore_evas_sdl_event_video_expose, NULL);
+   ecore_event_evas_init();
+
+   ecore_evas_event_handlers[0] = ecore_event_handler_add(ECORE_SDL_EVENT_GOT_FOCUS, _ecore_evas_sdl_event_got_focus, NULL);
+   ecore_evas_event_handlers[1] = ecore_event_handler_add(ECORE_SDL_EVENT_LOST_FOCUS, _ecore_evas_sdl_event_lost_focus, NULL);
+   ecore_evas_event_handlers[2] = ecore_event_handler_add(ECORE_SDL_EVENT_RESIZE, _ecore_evas_sdl_event_video_resize, NULL);
+   ecore_evas_event_handlers[3] = ecore_event_handler_add(ECORE_SDL_EVENT_EXPOSE, _ecore_evas_sdl_event_video_expose, NULL);
 
    return _ecore_evas_init_count;
 }
@@ -310,12 +204,14 @@ _ecore_evas_sdl_shutdown(void)
      {
 	int i;
 
-	while (ecore_evases) _ecore_evas_free(ecore_evases);
+        while (ecore_evases) _ecore_evas_free(ecore_evases);
+
         for (i = 0; i < sizeof (ecore_evas_event_handlers) / sizeof (Ecore_Event_Handler*); i++)
 	  ecore_event_handler_del(ecore_evas_event_handlers[i]);
+	ecore_event_evas_shutdown();
 	ecore_idle_enterer_del(ecore_evas_idle_enterer);
 	ecore_evas_idle_enterer = NULL;
-        ecore_timer_del(ecore_evas_event);
+        ecore_poller_del(ecore_evas_event);
         ecore_evas_event = NULL;
 #ifndef _WIN32
 	if (_ecore_evas_fps_debug) _ecore_evas_fps_debug_shutdown();
@@ -328,7 +224,8 @@ _ecore_evas_sdl_shutdown(void)
 static void
 _ecore_evas_sdl_free(Ecore_Evas *ee)
 {
-   ecore_evases = _ecore_list2_remove(ecore_evases, ee);
+   ecore_evases = (Ecore_Evas *) eina_inlist_remove(EINA_INLIST_GET(ecore_evases), EINA_INLIST_GET(ee));
+   ecore_event_window_unregister(0);
    _ecore_evas_sdl_shutdown();
    ecore_sdl_shutdown();
 }
@@ -361,6 +258,16 @@ _ecore_evas_move_resize(Ecore_Evas *ee, int x __UNUSED__, int y __UNUSED__, int
    if (ee->func.fn_resize) ee->func.fn_resize(ee);
 }
 
+static void
+_ecore_evas_object_cursor_del(void *data, Evas *e __UNUSED__, Evas_Object *obj __UNUSED__, void *event_info __UNUSED__)
+{
+   Ecore_Evas *ee;
+
+   ee = data;
+   if (ee)
+     ee->prop.cursor.object = NULL;
+}
+
 static void
 _ecore_evas_object_cursor_set(Ecore_Evas *ee, Evas_Object *obj, int layer, int hot_x, int hot_y)
 {
@@ -389,6 +296,8 @@ _ecore_evas_object_cursor_set(Ecore_Evas *ee, Evas_Object *obj, int layer, int h
    evas_object_pass_events_set(ee->prop.cursor.object, 1);
    if (evas_pointer_inside_get(ee->evas))
      evas_object_show(ee->prop.cursor.object);
+
+   evas_object_event_callback_add(obj, EVAS_CALLBACK_DEL, _ecore_evas_object_cursor_del, ee);
 }
 
 static const Ecore_Evas_Engine_Func _ecore_sdl_engine_func =
@@ -436,6 +345,7 @@ static const Ecore_Evas_Engine_Func _ecore_sdl_engine_func =
    NULL,
    NULL,
    NULL,
+   NULL,
    NULL
 };
 
@@ -450,15 +360,11 @@ _ecore_evas_internal_sdl_new(int rmethod, const char* name, int w, int h, int fu
 
    if (ecore_evases) return NULL;
 
-   if (!ecore_sdl_init(name)) return NULL;
-
    ee = calloc(1, sizeof(Ecore_Evas));
    if (!ee) return NULL;
 
    ECORE_MAGIC_SET(ee, ECORE_MAGIC_EVAS);
 
-   _ecore_evas_sdl_init(w, h);
-
    ee->engine.func = (Ecore_Evas_Engine_Func *)&_ecore_sdl_engine_func;
 
    ee->driver = "sdl";
@@ -480,6 +386,7 @@ _ecore_evas_internal_sdl_new(int rmethod, const char* name, int w, int h, int fu
    ee->prop.fullscreen = fullscreen;
    ee->prop.withdrawn = 0;
    ee->prop.sticky = 0;
+   ee->prop.window = 0;
 
    /* init evas here */
    ee->evas = evas_new();
@@ -499,53 +406,70 @@ _ecore_evas_internal_sdl_new(int rmethod, const char* name, int w, int h, int fu
         einfo->info.alpha = alpha;
         evas_engine_info_set(ee->evas, (Evas_Engine_Info *)einfo);
      }
-   evas_key_modifier_add(ee->evas, "Shift");
-   evas_key_modifier_add(ee->evas, "Control");
-   evas_key_modifier_add(ee->evas, "Alt");
-   evas_key_modifier_add(ee->evas, "Meta");
-   evas_key_modifier_add(ee->evas, "Hyper");
-   evas_key_modifier_add(ee->evas, "Super");
-   evas_key_lock_add(ee->evas, "Caps_Lock");
-   evas_key_lock_add(ee->evas, "Num_Lock");
-   evas_key_lock_add(ee->evas, "Scroll_Lock");
+
+   if (!ecore_sdl_init(name))
+     {
+	evas_free(ee->evas);
+	if (ee->name) free(ee->name);
+	free(ee);
+	return NULL;
+     }
+
+   _ecore_evas_sdl_init(w, h);
+
+   ecore_event_window_register(0, ee, ee->evas, (Ecore_Event_Mouse_Move_Cb) _ecore_evas_mouse_move_process);
 
    evas_event_feed_mouse_in(ee->evas, (unsigned int)((unsigned long long)(ecore_time_get() * 1000.0) & 0xffffffff), NULL);
 
    SDL_ShowCursor(SDL_DISABLE);
 
-   ecore_evases = _ecore_list2_prepend(ecore_evases, ee);
+   ecore_evases = (Ecore_Evas *) eina_inlist_prepend(EINA_INLIST_GET(ecore_evases), EINA_INLIST_GET(ee));
    return ee;
 }
 #endif
 
+#ifdef BUILD_ECORE_EVAS_SOFTWARE_SDL
 EAPI Ecore_Evas*
 ecore_evas_sdl_new(const char* name, int w, int h, int fullscreen, int hwsurface, int noframe, int alpha)
 {
-#ifdef BUILD_ECORE_EVAS_SDL
+   Ecore_Evas          *ee;
    int                  rmethod;
 
    rmethod = evas_render_method_lookup("software_sdl");
    if (!rmethod) return NULL;
 
-   return _ecore_evas_internal_sdl_new(rmethod, name, w, h, fullscreen, hwsurface, noframe, alpha);
-#else
-   fprintf(stderr, "OUTCH !\n");
-   return NULL;
-#endif
+   ee = _ecore_evas_internal_sdl_new(rmethod, name, w, h, fullscreen, hwsurface, noframe, alpha);
+   ee->driver = "sdl";
+   return ee;
 }
+#else
+EAPI Ecore_Evas*
+ecore_evas_sdl_new(const char* name __UNUSED__, int w __UNUSED__, int h __UNUSED__, int fullscreen __UNUSED__, int hwsurface __UNUSED__, int noframe __UNUSED__, int alpha __UNUSED__)
+{
+   ERR("OUTCH !");
+   return NULL;
+}
+#endif
 
+#ifdef BUILD_ECORE_EVAS_SOFTWARE_SDL
 EAPI Ecore_Evas*
 ecore_evas_sdl16_new(const char* name, int w, int h, int fullscreen, int hwsurface, int noframe, int alpha)
 {
-#ifdef BUILD_ECORE_EVAS_SDL
+   Ecore_Evas          *ee;
    int                  rmethod;
 
    rmethod = evas_render_method_lookup("software_16_sdl");
    if (!rmethod) return NULL;
 
-   return _ecore_evas_internal_sdl_new(rmethod, name, w, h, fullscreen, hwsurface, noframe, alpha);
-#else
-   fprintf(stderr, "OUTCH !\n");
-   return NULL;
-#endif
+   ee = _ecore_evas_internal_sdl_new(rmethod, name, w, h, fullscreen, hwsurface, noframe, alpha);
+   ee->driver = "software_16_sdl";
+   return ee;
 }
+#else
+EAPI Ecore_Evas*
+ecore_evas_sdl16_new(const char* name __UNUSED__, int w __UNUSED__, int h __UNUSED__, int fullscreen __UNUSED__, int hwsurface __UNUSED__, int noframe __UNUSED__, int alpha __UNUSED__)
+{
+   ERR("OUTCH !");
+   return NULL;
+}
+#endif
