@@ -31,7 +31,6 @@ static int _ecore_evas_fps_debug  = 0;
 static Ecore_Event_Handler *ecore_evas_event_handlers[ECORE_EVAS_EVENT_COUNT];
 static Ecore_Idle_Enterer  *ecore_evas_idle_enterer = NULL;
 static Ecore_Evas          *ecore_evases = NULL;
-static Eina_Hash           *ecore_evases_hash = NULL;
 
 static int _ecore_evas_wince_event_mouse_in(void *data __UNUSED__, int type __UNUSED__, void *event);
 
@@ -93,7 +92,7 @@ _ecore_evas_wince_render(Ecore_Evas *ee)
 static int
 _ecore_evas_wince_idle_enter(void *data __UNUSED__)
 {
-   Ecore_List2 *l;
+   Ecore_Evas *ee;
    double       t1 = 0.0;
    double       t2 = 0.0;
 
@@ -102,13 +101,9 @@ _ecore_evas_wince_idle_enter(void *data __UNUSED__)
      {
 	t1 = ecore_time_get();
      }
-   for (l = (Ecore_List2 *)ecore_evases; l; l = l->next)
-     {
-	Ecore_Evas *ee;
-
-	ee = (Ecore_Evas *)l;
+   EINA_INLIST_FOREACH(ecore_evases, ee)
 	_ecore_evas_wince_render(ee);
-     }
+
    if (_ecore_evas_fps_debug)
      {
 	t2 = ecore_time_get();
@@ -171,7 +166,7 @@ _ecore_evas_wince_event_mouse_in(void *data __UNUSED__, int type __UNUSED__, voi
    Ecore_Evas                 *ee;
    Ecore_WinCE_Event_Mouse_In *e;
 
-   EINA_ERROR_PINFO("mouse in\n");
+   INF("mouse in");
 
    e = event;
    ee = ecore_event_window_match((Ecore_Window)e->window);
@@ -193,7 +188,7 @@ _ecore_evas_wince_event_mouse_out(void *data __UNUSED__, int type __UNUSED__, vo
    Ecore_Evas                  *ee;
    Ecore_WinCE_Event_Mouse_Out *e;
 
-   EINA_ERROR_PINFO("mouse out\n");
+   INF("mouse out");
 
    e = event;
    ee = ecore_event_window_match((Ecore_Window)e->window);
@@ -217,7 +212,7 @@ _ecore_evas_wince_event_window_damage(void *data __UNUSED__, int type __UNUSED__
    Ecore_Evas                      *ee;
    Ecore_WinCE_Event_Window_Damage *e;
 
-   EINA_ERROR_PINFO("window damage\n");
+   INF("window damage");
 
    e = event;
    ee = ecore_event_window_match((Ecore_Window)e->window);
@@ -265,7 +260,7 @@ _ecore_evas_wince_event_window_destroy(void *data __UNUSED__, int type __UNUSED_
    Ecore_Evas                       *ee;
    Ecore_WinCE_Event_Window_Destroy *e;
 
-   EINA_ERROR_PINFO("window destroy\n");
+   INF("window destroy");
 
    e = event;
    ee = ecore_event_window_match((Ecore_Window)e->window);
@@ -283,7 +278,7 @@ _ecore_evas_wince_event_window_show(void *data __UNUSED__, int type __UNUSED__,
    Ecore_Evas                    *ee;
    Ecore_WinCE_Event_Window_Show *e;
 
-   EINA_ERROR_PINFO("window show\n");
+   INF("window show");
 
    e = event;
    ee = ecore_event_window_match((Ecore_Window)e->window);
@@ -302,7 +297,7 @@ _ecore_evas_wince_event_window_hide(void *data __UNUSED__, int type __UNUSED__,
    Ecore_Evas                    *ee;
    Ecore_WinCE_Event_Window_Hide *e;
 
-   EINA_ERROR_PINFO("window hide\n");
+   INF("window hide");
 
    e = event;
    ee = ecore_event_window_match((Ecore_Window)e->window);
@@ -321,7 +316,7 @@ _ecore_evas_wince_event_window_delete_request(void *data __UNUSED__, int type __
    Ecore_Evas                              *ee;
    Ecore_WinCE_Event_Window_Delete_Request *e;
 
-   EINA_ERROR_PINFO("window delete request\n");
+   INF("window delete request");
 
    e = event;
    ee = ecore_event_window_match((Ecore_Window)e->window);
@@ -338,11 +333,11 @@ _ecore_evas_wince_event_window_delete_request(void *data __UNUSED__, int type __
 static void
 _ecore_evas_wince_free(Ecore_Evas *ee)
 {
-   EINA_ERROR_PINFO("ecore evas free\n");
+   INF("ecore evas free");
 
    ecore_wince_window_free((Ecore_WinCE_Window *)ee->prop.window);
    ecore_event_window_unregister(ee->prop.window);
-   ecore_evases = _ecore_list2_remove(ecore_evases, ee);
+   ecore_evases = (Ecore_Evas *) eina_inlist_remove(EINA_INLIST_GET(ecore_evases), EINA_INLIST_GET(ee));
    _ecore_evas_wince_shutdown();
    ecore_wince_shutdown();
 }
@@ -357,7 +352,7 @@ _ecore_evas_wince_callback_delete_request_set(Ecore_Evas *ee,
 static void
 _ecore_evas_wince_move(Ecore_Evas *ee, int x, int y)
 {
-  EINA_ERROR_PINFO("ecore evas move (%dx%d)\n", x, y);
+  INF("ecore evas move (%dx%d)", x, y);
 
    if ((x != ee->x) || (y != ee->y))
      {
@@ -371,7 +366,7 @@ _ecore_evas_wince_move(Ecore_Evas *ee, int x, int y)
 static void
 _ecore_evas_wince_resize(Ecore_Evas *ee, int width, int height)
 {
-   EINA_ERROR_PINFO("ecore evas resize (%dx%d)\n", width, height);
+   INF("ecore evas resize (%dx%d)", width, height);
 
    if ((ee->w != width) || (ee->h != height))
      {
@@ -397,7 +392,7 @@ _ecore_evas_wince_resize(Ecore_Evas *ee, int width, int height)
 static void
 _ecore_evas_wince_move_resize(Ecore_Evas *ee, int x, int y, int width, int height)
 {
-   EINA_ERROR_PINFO("ecore evas resize (%dx%d %dx%d)\n", x, y, width, height);
+   INF("ecore evas resize (%dx%d %dx%d)", x, y, width, height);
 
    if ((ee->w != width) || (ee->h != height) || (x != ee->x) || (y != ee->y))
      {
@@ -509,7 +504,7 @@ _ecore_evas_wince_move_resize(Ecore_Evas *ee, int x, int y, int width, int heigh
 static void
 _ecore_evas_wince_show(Ecore_Evas *ee)
 {
-   EINA_ERROR_PINFO("ecore evas show\n");
+   INF("ecore evas show");
 
    ee->should_be_visible = 1;
    if (ee->prop.avoid_damage)
@@ -522,7 +517,7 @@ _ecore_evas_wince_show(Ecore_Evas *ee)
 static void
 _ecore_evas_wince_hide(Ecore_Evas *ee)
 {
-   EINA_ERROR_PINFO("ecore evas hide\n");
+   INF("ecore evas hide");
 
    ecore_wince_window_hide((Ecore_WinCE_Window *)ee->prop.window);
    ee->should_be_visible = 0;
@@ -549,7 +544,7 @@ _ecore_evas_wince_hide(Ecore_Evas *ee)
 static void
 _ecore_evas_wince_title_set(Ecore_Evas *ee, const char *title)
 {
-   EINA_ERROR_PINFO("ecore evas title set\n");
+   INF("ecore evas title set");
 
    if (ee->prop.title) free(ee->prop.title);
    ee->prop.title = NULL;
@@ -667,7 +662,7 @@ _ecore_evas_wince_fullscreen_set(Ecore_Evas *ee, int on)
    Evas_Engine_Info_Software_16_WinCE *einfo;
    struct _Ecore_WinCE_Window         *window;
 
-   EINA_ERROR_PINFO("ecore evas fullscreen set\n");
+   INF("ecore evas fullscreen set");
 
    if ((ee->engine.wince.state.fullscreen && on) ||
       (!ee->engine.wince.state.fullscreen && !on))
@@ -853,7 +848,7 @@ ecore_evas_software_wince_new_internal(int                 backend,
         ecore_wince_window_resume_set((Ecore_WinCE_Window *)ee->prop.window, einfo->func.resume);
      }
 
-   ecore_evases = _ecore_list2_prepend(ecore_evases, ee);
+   ecore_evases = (Ecore_Evas *) eina_inlist_prepend(EINA_INLIST_GET(ecore_evases), EINA_INLIST_GET(ee));
    ecore_event_window_register(ee->prop.window, ee, ee->evas, (Ecore_Event_Mouse_Move_Cb)_ecore_evas_mouse_move_process);
 
    return ee;
