@@ -12,9 +12,10 @@
 #include "Ecore_Con.h"
 #include "ecore_file_private.h"
 
+#ifdef BUILD_ECORE_CON
+
 #define ECORE_MAGIC_FILE_DOWNLOAD_JOB	0xf7427cb8
 
-typedef struct _Ecore_File_Download_Job		Ecore_File_Download_Job;
 struct _Ecore_File_Download_Job
 {
    ECORE_MAGIC;
@@ -40,67 +41,63 @@ Ecore_File_Download_Job *_ecore_file_download_curl(const char *url, const char *
 static int _ecore_file_download_url_complete_cb(void *data, int type, void *event);
 static int _ecore_file_download_url_progress_cb(void *data, int type, void *event);
 #endif
-static void _ecore_file_download_abort(Ecore_File_Download_Job *job);
 
-static int			 init = 0;
 static Ecore_Event_Handler	*_url_complete_handler = NULL;
 static Ecore_Event_Handler	*_url_progress_download = NULL;
 static Eina_List		*_job_list;
 
-EAPI int
+#endif /* BUILD_ECORE_CON */
+
+int
 ecore_file_download_init(void)
 {
-#ifndef _WIN32
-   ecore_con_url_init();
+#ifdef BUILD_ECORE_CON
+  if (!ecore_con_url_init())
+    return 0;
 
-   if (init++ == 0)
-     {
-#ifdef HAVE_CURL
-	_url_complete_handler = ecore_event_handler_add(ECORE_CON_EVENT_URL_COMPLETE, _ecore_file_download_url_complete_cb, NULL);
-	_url_progress_download = ecore_event_handler_add(ECORE_CON_EVENT_URL_PROGRESS, _ecore_file_download_url_progress_cb, NULL);
-#endif
-     }
+# ifdef HAVE_CURL
+  _url_complete_handler = ecore_event_handler_add(ECORE_CON_EVENT_URL_COMPLETE, _ecore_file_download_url_complete_cb, NULL);
+  _url_progress_download = ecore_event_handler_add(ECORE_CON_EVENT_URL_PROGRESS, _ecore_file_download_url_progress_cb, NULL);
+# endif
+
+#endif /* BUILD_ECORE_CON */
 
    return 1;
-#else
-   return 0;
-#endif
 }
 
-EAPI int
+void
 ecore_file_download_shutdown(void)
 {
-#ifndef _WIN32
-   if (--init == 0)
-     {
-	if (_url_complete_handler)
-	  ecore_event_handler_del(_url_complete_handler);
-	if (_url_progress_download)
-	  ecore_event_handler_del(_url_progress_download);
-	_url_complete_handler = NULL;
-	_url_progress_download = NULL;
-	ecore_file_download_abort_all();
-     }
+#ifdef BUILD_ECORE_CON
+  if (_url_complete_handler)
+    ecore_event_handler_del(_url_complete_handler);
+  if (_url_progress_download)
+    ecore_event_handler_del(_url_progress_download);
+  _url_complete_handler = NULL;
+  _url_progress_download = NULL;
+  ecore_file_download_abort_all();
 
-   return ecore_con_url_shutdown();
-#else
-   return 0;
-#endif
+  ecore_con_url_shutdown();
+#endif /* BUILD_ECORE_CON */
 }
 
 EAPI void
 ecore_file_download_abort_all(void)
 {
-	Ecore_File_Download_Job *job;
+#ifdef BUILD_ECORE_CON
+   Ecore_File_Download_Job *job;
 
    EINA_LIST_FREE(_job_list, job)
-	     _ecore_file_download_abort(job);
+	     ecore_file_download_abort(job);
+#endif /* BUILD_ECORE_CON */
 }
 
 /**
  * Download @p url to the given @p dst
  * @param  url The complete url to download
  * @param  dst The local file to save the downloaded to
+ * @param  job_ret If the protocol use is http or ftp, this parameter will be fill
+ *	with the job. Then you can use ecore_file_download_abort() to cancel it.
  * @param  completion_cb A callback called on download complete
  * @param  progress_cb A callback called during the download operation
  * @return 1 if the download start or 0 on failure
@@ -113,8 +110,9 @@ EAPI int
 ecore_file_download(const char *url, const char *dst,
 		    void (*completion_cb)(void *data, const char *file, int status),
 		    int (*progress_cb)(void *data, const char *file, long int dltotal, long int dlnow, long int ultotal, long int ulnow),
-		    void *data)
+		    void *data, Ecore_File_Download_Job **job_ret)
 {
+#ifdef BUILD_ECORE_CON
    char *dir = ecore_file_dir_get(dst);
 
    if (!ecore_file_is_dir(dir))
@@ -137,7 +135,7 @@ ecore_file_download(const char *url, const char *dst,
 	url = strchr(url, '/');
 	return ecore_file_cp(url, dst);
      }
-#ifdef HAVE_CURL
+# ifdef HAVE_CURL
    else if ((!strncmp(url, "http://", 7)) ||
 	    (!strncmp(url, "ftp://", 6)))
      {
@@ -145,21 +143,20 @@ ecore_file_download(const char *url, const char *dst,
 	Ecore_File_Download_Job *job;
 
 	job = _ecore_file_download_curl(url, dst, completion_cb, progress_cb, data);
-	if (job)
-	  return 1;
-	else
-	  return 0;
+	if(job_ret) *job_ret = job;
+	return job != NULL;
      }
-#endif
+# endif
    else
      {
 	return 0;
      }
-#ifndef HAVE_CURL
+#else
    completion_cb = NULL;
    progress_cb = NULL;
    data = NULL;
-#endif
+   return 0;
+#endif /* BUILD_ECORE_CON */
 }
 
 /**
@@ -173,16 +170,20 @@ ecore_file_download(const char *url, const char *dst,
 EAPI int
 ecore_file_download_protocol_available(const char *protocol)
 {
+#ifdef BUILD_ECORE_CON
    if (!strncmp(protocol, "file://", 7)) return 1;
-#ifdef HAVE_CURL
+# ifdef HAVE_CURL
    else if (!strncmp(protocol, "http://", 7)) return 1;
    else if (!strncmp(protocol, "ftp://", 6)) return 1;
-#endif
+# endif
+#endif /* BUILD_ECORE_CON */
 
    return 0;
 }
 
-#ifdef HAVE_CURL
+#ifdef BUILD_ECORE_CON
+
+# ifdef HAVE_CURL
 static int
 _ecore_file_download_url_compare_job(const void *data1, const void *data2)
 {
@@ -202,12 +203,14 @@ _ecore_file_download_url_complete_cb(void *data, int type, void *event)
    job = eina_list_search_unsorted(_job_list, _ecore_file_download_url_compare_job, ev->url_con);
    if (!ECORE_MAGIC_CHECK(job, ECORE_MAGIC_FILE_DOWNLOAD_JOB)) return 1;
 
-   _job_list = eina_list_remove(_job_list, job);
 
    if (job->completion_cb)
      job->completion_cb(ecore_con_url_data_get(job->url_con), job->dst, !ev->status);
 
-   _ecore_file_download_abort(job);
+   _job_list = eina_list_remove(_job_list, job);
+   fclose(job->file);
+   free(job->dst);
+   free(job);
 
    return 0;
 }
@@ -229,7 +232,11 @@ _ecore_file_download_url_progress_cb(void *data, int type, void *event)
 			  (long int) ev->up.total, (long int) ev->up.now) != 0)
        {
 	  _job_list = eina_list_remove(_job_list, job);
-	  _ecore_file_download_abort(job);
+	  fclose(job->file);
+	  free(job->dst);
+	  free(job);
+
+	  return 1;
        }
 
    return 0;
@@ -278,15 +285,19 @@ _ecore_file_download_curl(const char *url, const char *dst,
 
    return job;
 }
+# endif
 #endif
 
-static void
-_ecore_file_download_abort(Ecore_File_Download_Job *job)
+EAPI void
+ecore_file_download_abort(Ecore_File_Download_Job *job)
 {
-#ifdef HAVE_CURL
+#ifdef BUILD_ECORE_CON
+# ifdef HAVE_CURL
    ecore_con_url_destroy(job->url_con);
-#endif  
+# endif
+   _job_list = eina_list_remove(_job_list, job);
    fclose(job->file);
    free(job->dst);
    free(job);
+#endif /* BUILD_ECORE_CON */
 }
