@@ -3,8 +3,10 @@
 
 #include "Ecore_Data.h"
 
-#if USE_OPENSSL
-#include <openssl/ssl.h>
+#if USE_GNUTLS_OPENSSL
+# include <gnutls/openssl.h>
+#elif USE_OPENSSL
+# include <openssl/ssl.h>
 #endif
 
 #define ECORE_MAGIC_IPC_SERVER             0x87786556
@@ -37,7 +39,6 @@ __attribute__ ((packed));
 
 struct _Ecore_Ipc_Client
 {
-   Ecore_List        __list_data;
    ECORE_MAGIC;
    Ecore_Con_Client  *client;
    void              *data;
@@ -55,11 +56,10 @@ struct _Ecore_Ipc_Client
    
 struct _Ecore_Ipc_Server
 {
-   Ecore_List        __list_data;
    ECORE_MAGIC;
    Ecore_Con_Server *server;
-   Ecore_Ipc_Client *clients;
-   Ecore_List       *client_list;
+   Eina_List        *clients;
+   Eina_List        *client_list;
    void              *data;
    unsigned char     *buf;
    int                buf_size;
