@@ -143,6 +143,14 @@ typedef struct _Ecore_X_DND_Target
    int will_accept;
 } Ecore_X_DND_Target;
 
+extern int ECORE_X_MODIFIER_SHIFT;
+extern int ECORE_X_MODIFIER_CTRL; 
+extern int ECORE_X_MODIFIER_ALT; 
+extern int ECORE_X_MODIFIER_WIN; 
+ 
+extern int ECORE_X_LOCK_SCROLL; 
+extern int ECORE_X_LOCK_NUM; 
+extern int ECORE_X_LOCK_CAPS; 
 
 extern Ecore_X_Connection *_ecore_xcb_conn;
 extern Ecore_X_Screen     *_ecore_xcb_screen;
@@ -165,6 +173,7 @@ extern Ecore_X_Window      _ecore_xcb_private_window;
 
 void _ecore_x_error_handler_init(void);
 
+void _ecore_x_event_handle_any_event          (xcb_generic_event_t *event);
 void _ecore_x_event_handle_key_press          (xcb_generic_event_t *event);
 void _ecore_x_event_handle_key_release        (xcb_generic_event_t *event);
 void _ecore_x_event_handle_button_press       (xcb_generic_event_t *event);
@@ -235,7 +244,7 @@ extern Ecore_X_Atom ECORE_X_ATOM_WINDOW;
 extern Ecore_X_Atom ECORE_X_ATOM_E_FRAME_SIZE;
 extern Ecore_X_Atom ECORE_X_ATOM_WM_SIZE_HINTS;
 
-#define ECORE_X_ATOMS_COUNT 115
+#define ECORE_X_ATOMS_COUNT 117
 
 void _ecore_x_atom_init          (xcb_intern_atom_cookie_t *);
 void _ecore_x_atom_init_finalize (xcb_intern_atom_cookie_t *);
