@@ -494,7 +494,8 @@ ecore_x_window_focus(Ecore_X_Window win)
 {
    if (win == 0) win = DefaultRootWindow(_ecore_x_disp);   
 //   XSetInputFocus(_ecore_x_disp, win, RevertToNone, CurrentTime);
-   XSetInputFocus(_ecore_x_disp, win, RevertToPointerRoot, CurrentTime);
+//   XSetInputFocus(_ecore_x_disp, win, RevertToPointerRoot, CurrentTime);
+   XSetInputFocus(_ecore_x_disp, win, RevertToParent, CurrentTime);
 }
 
 /**
@@ -508,7 +509,8 @@ ecore_x_window_focus_at_time(Ecore_X_Window win, Ecore_X_Time t)
 {
    if (win == 0) win = DefaultRootWindow(_ecore_x_disp);   
 //   XSetInputFocus(_ecore_x_disp, win, RevertToNone, t);
-   XSetInputFocus(_ecore_x_disp, win, PointerRoot, t);
+//   XSetInputFocus(_ecore_x_disp, win, PointerRoot, t);
+   XSetInputFocus(_ecore_x_disp, win, RevertToParent, t);
 }
 
 /**
@@ -789,6 +791,7 @@ _ecore_x_window_tree_walk(Window win)
 	       }
 	  }
      }
+   if (list) XFree(list);
    return s;
 }
 
